@@ -180,6 +180,10 @@ static aom_image_t *img_alloc_helper(
     img->stride[AOM_PLANE_V] = 0;
   }
 
+  img->cp = AOM_CICP_CP_UNSPECIFIED;
+  img->tc = AOM_CICP_TC_UNSPECIFIED;
+  img->mc = AOM_CICP_MC_UNSPECIFIED;
+
   /* Default viewport to entire image. (This aom_img_set_rect call always
    * succeeds.) */
   int ret = aom_img_set_rect(img, 0, 0, d_w, d_h, border);
@@ -382,9 +386,9 @@ int aom_img_add_metadata(aom_image_t *img, uint32_t type, const uint8_t *data,
   aom_metadata_t *metadata =
       aom_img_metadata_alloc(type, data, sz, insert_flag);
   if (!metadata) return -1;
-  aom_metadata_t **metadata_array =
-      (aom_metadata_t **)realloc(img->metadata->metadata_array,
-                                 (img->metadata->sz + 1) * sizeof(metadata));
+  aom_metadata_t **metadata_array = (aom_metadata_t **)realloc(
+      img->metadata->metadata_array,
+      (img->metadata->sz + 1) * sizeof(*metadata_array));
   if (!metadata_array) {
     aom_img_metadata_free(metadata);
     return -1;
