@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -12,7 +12,7 @@
 #ifndef AOM_AOM_DSP_AOM_SIMD_INLINE_H_
 #define AOM_AOM_DSP_AOM_SIMD_INLINE_H_
 
-#include "aom/aom_integer.h"
+#include "aom_dsp/aom_dsp_common.h"
 
 #ifndef SIMD_INLINE
 #define SIMD_INLINE static AOM_FORCE_INLINE
