@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2023 The WebM project authors. All Rights Reserved.
- * Copyright (c) 2023, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2023 The WebM project authors. All rights reserved.
+ * Copyright (c) 2023, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -19,7 +19,7 @@
 #include "aom_dsp/arm/mem_neon.h"
 #include "aom_dsp/arm/sum_neon.h"
 
-static INLINE uint32_t highbd_sad4xh_small_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sad4xh_small_neon(const uint8_t *src_ptr,
                                                 int src_stride,
                                                 const uint8_t *ref_ptr,
                                                 int ref_stride, int h) {
@@ -40,7 +40,7 @@ static INLINE uint32_t highbd_sad4xh_small_neon(const uint8_t *src_ptr,
   return horizontal_add_u32x4(sum);
 }
 
-static INLINE uint32_t highbd_sad8xh_small_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sad8xh_small_neon(const uint8_t *src_ptr,
                                                 int src_stride,
                                                 const uint8_t *ref_ptr,
                                                 int ref_stride, int h) {
@@ -62,7 +62,7 @@ static INLINE uint32_t highbd_sad8xh_small_neon(const uint8_t *src_ptr,
 }
 
 #if !CONFIG_REALTIME_ONLY
-static INLINE uint32_t highbd_sad8xh_large_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sad8xh_large_neon(const uint8_t *src_ptr,
                                                 int src_stride,
                                                 const uint8_t *ref_ptr,
                                                 int ref_stride, int h) {
@@ -85,7 +85,7 @@ static INLINE uint32_t highbd_sad8xh_large_neon(const uint8_t *src_ptr,
 }
 #endif  // !CONFIG_REALTIME_ONLY
 
-static INLINE uint32_t highbd_sad16xh_large_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sad16xh_large_neon(const uint8_t *src_ptr,
                                                  int src_stride,
                                                  const uint8_t *ref_ptr,
                                                  int ref_stride, int h) {
@@ -113,7 +113,7 @@ static INLINE uint32_t highbd_sad16xh_large_neon(const uint8_t *src_ptr,
   return horizontal_add_u32x4(sum[0]);
 }
 
-static INLINE uint32_t highbd_sadwxh_large_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sadwxh_large_neon(const uint8_t *src_ptr,
                                                 int src_stride,
                                                 const uint8_t *ref_ptr,
                                                 int ref_stride, int w, int h) {
@@ -160,7 +160,7 @@ static INLINE uint32_t highbd_sadwxh_large_neon(const uint8_t *src_ptr,
   return horizontal_add_u32x4(sum[0]);
 }
 
-static INLINE unsigned int highbd_sad128xh_large_neon(const uint8_t *src_ptr,
+static inline unsigned int highbd_sad128xh_large_neon(const uint8_t *src_ptr,
                                                       int src_stride,
                                                       const uint8_t *ref_ptr,
                                                       int ref_stride, int h) {
@@ -168,7 +168,7 @@ static INLINE unsigned int highbd_sad128xh_large_neon(const uint8_t *src_ptr,
                                   h);
 }
 
-static INLINE unsigned int highbd_sad64xh_large_neon(const uint8_t *src_ptr,
+static inline unsigned int highbd_sad64xh_large_neon(const uint8_t *src_ptr,
                                                      int src_stride,
                                                      const uint8_t *ref_ptr,
                                                      int ref_stride, int h) {
@@ -176,7 +176,7 @@ static INLINE unsigned int highbd_sad64xh_large_neon(const uint8_t *src_ptr,
                                   h);
 }
 
-static INLINE unsigned int highbd_sad32xh_large_neon(const uint8_t *src_ptr,
+static inline unsigned int highbd_sad32xh_large_neon(const uint8_t *src_ptr,
                                                      int src_stride,
                                                      const uint8_t *ref_ptr,
                                                      int ref_stride, int h) {
@@ -251,14 +251,8 @@ HBD_SAD_WXH_LARGE_NEON(64, 16)
                                             2 * ref_stride, (h) / 2); \
   }
 
-HBD_SAD_SKIP_WXH_SMALL_NEON(4, 4)
-HBD_SAD_SKIP_WXH_SMALL_NEON(4, 8)
-
-HBD_SAD_SKIP_WXH_SMALL_NEON(8, 4)
-HBD_SAD_SKIP_WXH_SMALL_NEON(8, 8)
 HBD_SAD_SKIP_WXH_SMALL_NEON(8, 16)
 
-HBD_SAD_SKIP_WXH_LARGE_NEON(16, 8)
 HBD_SAD_SKIP_WXH_LARGE_NEON(16, 16)
 HBD_SAD_SKIP_WXH_LARGE_NEON(16, 32)
 
@@ -278,42 +272,12 @@ HBD_SAD_SKIP_WXH_SMALL_NEON(4, 16)
 
 HBD_SAD_SKIP_WXH_SMALL_NEON(8, 32)
 
-HBD_SAD_SKIP_WXH_LARGE_NEON(16, 4)
 HBD_SAD_SKIP_WXH_LARGE_NEON(16, 64)
 
-HBD_SAD_SKIP_WXH_LARGE_NEON(32, 8)
-
 HBD_SAD_SKIP_WXH_LARGE_NEON(64, 16)
 #endif  // !CONFIG_REALTIME_ONLY
 
-static INLINE uint32_t highbd_sad4xh_avg_neon(const uint8_t *src_ptr,
-                                              int src_stride,
-                                              const uint8_t *ref_ptr,
-                                              int ref_stride, int h,
-                                              const uint8_t *second_pred) {
-  const uint16_t *src16_ptr = CONVERT_TO_SHORTPTR(src_ptr);
-  const uint16_t *ref16_ptr = CONVERT_TO_SHORTPTR(ref_ptr);
-  const uint16_t *pred16_ptr = CONVERT_TO_SHORTPTR(second_pred);
-  uint32x4_t sum = vdupq_n_u32(0);
-
-  int i = h;
-  do {
-    uint16x4_t s = vld1_u16(src16_ptr);
-    uint16x4_t r = vld1_u16(ref16_ptr);
-    uint16x4_t p = vld1_u16(pred16_ptr);
-
-    uint16x4_t avg = vrhadd_u16(r, p);
-    sum = vabal_u16(sum, s, avg);
-
-    src16_ptr += src_stride;
-    ref16_ptr += ref_stride;
-    pred16_ptr += 4;
-  } while (--i != 0);
-
-  return horizontal_add_u32x4(sum);
-}
-
-static INLINE uint32_t highbd_sad8xh_avg_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sad8xh_avg_neon(const uint8_t *src_ptr,
                                               int src_stride,
                                               const uint8_t *ref_ptr,
                                               int ref_stride, int h,
@@ -341,7 +305,7 @@ static INLINE uint32_t highbd_sad8xh_avg_neon(const uint8_t *src_ptr,
   return horizontal_add_u32x4(sum);
 }
 
-static INLINE uint32_t highbd_sad16xh_avg_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sad16xh_avg_neon(const uint8_t *src_ptr,
                                                int src_stride,
                                                const uint8_t *ref_ptr,
                                                int ref_stride, int h,
@@ -379,7 +343,7 @@ static INLINE uint32_t highbd_sad16xh_avg_neon(const uint8_t *src_ptr,
   return horizontal_add_u32x4(sum[0]);
 }
 
-static INLINE uint32_t highbd_sadwxh_avg_neon(const uint8_t *src_ptr,
+static inline uint32_t highbd_sadwxh_avg_neon(const uint8_t *src_ptr,
                                               int src_stride,
                                               const uint8_t *ref_ptr,
                                               int ref_stride, int w, int h,
@@ -440,14 +404,14 @@ static INLINE uint32_t highbd_sadwxh_avg_neon(const uint8_t *src_ptr,
   return horizontal_add_u32x4(sum[0]);
 }
 
-static INLINE unsigned int highbd_sad128xh_avg_neon(
+static inline unsigned int highbd_sad128xh_avg_neon(
     const uint8_t *src_ptr, int src_stride, const uint8_t *ref_ptr,
     int ref_stride, int h, const uint8_t *second_pred) {
   return highbd_sadwxh_avg_neon(src_ptr, src_stride, ref_ptr, ref_stride, 128,
                                 h, second_pred);
 }
 
-static INLINE unsigned int highbd_sad64xh_avg_neon(const uint8_t *src_ptr,
+static inline unsigned int highbd_sad64xh_avg_neon(const uint8_t *src_ptr,
                                                    int src_stride,
                                                    const uint8_t *ref_ptr,
                                                    int ref_stride, int h,
@@ -456,7 +420,7 @@ static INLINE unsigned int highbd_sad64xh_avg_neon(const uint8_t *src_ptr,
                                 second_pred);
 }
 
-static INLINE unsigned int highbd_sad32xh_avg_neon(const uint8_t *src_ptr,
+static inline unsigned int highbd_sad32xh_avg_neon(const uint8_t *src_ptr,
                                                    int src_stride,
                                                    const uint8_t *ref_ptr,
                                                    int ref_stride, int h,
@@ -473,10 +437,6 @@ static INLINE unsigned int highbd_sad32xh_avg_neon(const uint8_t *src_ptr,
                                       second_pred);                           \
   }
 
-HBD_SAD_WXH_AVG_NEON(4, 4)
-HBD_SAD_WXH_AVG_NEON(4, 8)
-
-HBD_SAD_WXH_AVG_NEON(8, 4)
 HBD_SAD_WXH_AVG_NEON(8, 8)
 HBD_SAD_WXH_AVG_NEON(8, 16)
 
@@ -496,11 +456,8 @@ HBD_SAD_WXH_AVG_NEON(128, 64)
 HBD_SAD_WXH_AVG_NEON(128, 128)
 
 #if !CONFIG_REALTIME_ONLY
-HBD_SAD_WXH_AVG_NEON(4, 16)
-
 HBD_SAD_WXH_AVG_NEON(8, 32)
 
-HBD_SAD_WXH_AVG_NEON(16, 4)
 HBD_SAD_WXH_AVG_NEON(16, 64)
 
 HBD_SAD_WXH_AVG_NEON(32, 8)
