@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -16,14 +16,15 @@
 
 // Although we assign 32 bit integers, all the values are strictly under 14
 // bits.
-static int div_mult[32] = { 0,    16384, 8192, 5461, 4096, 3276, 2730, 2340,
-                            2048, 1820,  1638, 1489, 1365, 1260, 1170, 1092,
-                            1024, 963,   910,  862,  819,  780,  744,  712,
-                            682,  655,   630,  606,  585,  564,  546,  528 };
+static const int div_mult[32] = { 0,    16384, 8192, 5461, 4096, 3276, 2730,
+                                  2340, 2048,  1820, 1638, 1489, 1365, 1260,
+                                  1170, 1092,  1024, 963,  910,  862,  819,
+                                  780,  744,   712,  682,  655,  630,  606,
+                                  585,  564,   546,  528 };
 
 // TODO(jingning): Consider the use of lookup table for (num / den)
 // altogether.
-static AOM_INLINE void get_mv_projection(MV *output, MV ref, int num, int den) {
+void av1_get_mv_projection(MV *output, MV ref, int num, int den) {
   den = AOMMIN(den, MAX_FRAME_DISTANCE);
   num = num > 0 ? AOMMIN(num, MAX_FRAME_DISTANCE)
                 : AOMMAX(num, -MAX_FRAME_DISTANCE);
@@ -71,7 +72,7 @@ void av1_copy_frame_mvs(const AV1_COMMON *const cm,
   }
 }
 
-static AOM_INLINE void add_ref_mv_candidate(
+static inline void add_ref_mv_candidate(
     const MB_MODE_INFO *const candidate, const MV_REFERENCE_FRAME rf[2],
     uint8_t *refmv_count, uint8_t *ref_match_count, uint8_t *newmv_count,
     CANDIDATE_MV *ref_mv_stack, uint16_t *ref_mv_weight,
@@ -139,12 +140,13 @@ static AOM_INLINE void add_ref_mv_candidate(
   }
 }
 
-static AOM_INLINE void scan_row_mbmi(
-    const AV1_COMMON *cm, const MACROBLOCKD *xd, int mi_col,
-    const MV_REFERENCE_FRAME rf[2], int row_offset, CANDIDATE_MV *ref_mv_stack,
-    uint16_t *ref_mv_weight, uint8_t *refmv_count, uint8_t *ref_match_count,
-    uint8_t *newmv_count, int_mv *gm_mv_candidates, int max_row_offset,
-    int *processed_rows) {
+static inline void scan_row_mbmi(const AV1_COMMON *cm, const MACROBLOCKD *xd,
+                                 int mi_col, const MV_REFERENCE_FRAME rf[2],
+                                 int row_offset, CANDIDATE_MV *ref_mv_stack,
+                                 uint16_t *ref_mv_weight, uint8_t *refmv_count,
+                                 uint8_t *ref_match_count, uint8_t *newmv_count,
+                                 int_mv *gm_mv_candidates, int max_row_offset,
+                                 int *processed_rows) {
   int end_mi = AOMMIN(xd->width, cm->mi_params.mi_cols - mi_col);
   end_mi = AOMMIN(end_mi, mi_size_wide[BLOCK_64X64]);
   const int width_8x8 = mi_size_wide[BLOCK_8X8];
@@ -186,12 +188,13 @@ static AOM_INLINE void scan_row_mbmi(
   }
 }
 
-static AOM_INLINE void scan_col_mbmi(
-    const AV1_COMMON *cm, const MACROBLOCKD *xd, int mi_row,
-    const MV_REFERENCE_FRAME rf[2], int col_offset, CANDIDATE_MV *ref_mv_stack,
-    uint16_t *ref_mv_weight, uint8_t *refmv_count, uint8_t *ref_match_count,
-    uint8_t *newmv_count, int_mv *gm_mv_candidates, int max_col_offset,
-    int *processed_cols) {
+static inline void scan_col_mbmi(const AV1_COMMON *cm, const MACROBLOCKD *xd,
+                                 int mi_row, const MV_REFERENCE_FRAME rf[2],
+                                 int col_offset, CANDIDATE_MV *ref_mv_stack,
+                                 uint16_t *ref_mv_weight, uint8_t *refmv_count,
+                                 uint8_t *ref_match_count, uint8_t *newmv_count,
+                                 int_mv *gm_mv_candidates, int max_col_offset,
+                                 int *processed_cols) {
   int end_mi = AOMMIN(xd->height, cm->mi_params.mi_rows - mi_row);
   end_mi = AOMMIN(end_mi, mi_size_high[BLOCK_64X64]);
   const int n8_h_8 = mi_size_high[BLOCK_8X8];
@@ -233,12 +236,14 @@ static AOM_INLINE void scan_col_mbmi(
   }
 }
 
-static AOM_INLINE void scan_blk_mbmi(
-    const AV1_COMMON *cm, const MACROBLOCKD *xd, const int mi_row,
-    const int mi_col, const MV_REFERENCE_FRAME rf[2], int row_offset,
-    int col_offset, CANDIDATE_MV *ref_mv_stack, uint16_t *ref_mv_weight,
-    uint8_t *ref_match_count, uint8_t *newmv_count, int_mv *gm_mv_candidates,
-    uint8_t *refmv_count) {
+static inline void scan_blk_mbmi(const AV1_COMMON *cm, const MACROBLOCKD *xd,
+                                 const int mi_row, const int mi_col,
+                                 const MV_REFERENCE_FRAME rf[2], int row_offset,
+                                 int col_offset, CANDIDATE_MV *ref_mv_stack,
+                                 uint16_t *ref_mv_weight,
+                                 uint8_t *ref_match_count, uint8_t *newmv_count,
+                                 int_mv *gm_mv_candidates,
+                                 uint8_t *refmv_count) {
   const TileInfo *const tile = &xd->tile;
   POSITION mi_pos;
 
@@ -354,8 +359,8 @@ static int add_tpl_ref_mv(const AV1_COMMON *cm, const MACROBLOCKD *xd,
   const int force_integer_mv = cm->features.cur_frame_force_integer_mv;
 
   int_mv this_refmv;
-  get_mv_projection(&this_refmv.as_mv, prev_frame_mvs->mfmv0.as_mv,
-                    cur_offset_0, prev_frame_mvs->ref_frame_offset);
+  av1_get_mv_projection(&this_refmv.as_mv, prev_frame_mvs->mfmv0.as_mv,
+                        cur_offset_0, prev_frame_mvs->ref_frame_offset);
   lower_mv_precision(&this_refmv.as_mv, allow_high_precision_mv,
                      force_integer_mv);
 
@@ -383,8 +388,8 @@ static int add_tpl_ref_mv(const AV1_COMMON *cm, const MACROBLOCKD *xd,
     const int cur_offset_1 = get_relative_dist(&cm->seq_params->order_hint_info,
                                                cur_frame_index, frame1_index);
     int_mv comp_refmv;
-    get_mv_projection(&comp_refmv.as_mv, prev_frame_mvs->mfmv0.as_mv,
-                      cur_offset_1, prev_frame_mvs->ref_frame_offset);
+    av1_get_mv_projection(&comp_refmv.as_mv, prev_frame_mvs->mfmv0.as_mv,
+                          cur_offset_1, prev_frame_mvs->ref_frame_offset);
     lower_mv_precision(&comp_refmv.as_mv, allow_high_precision_mv,
                        force_integer_mv);
 
@@ -415,7 +420,7 @@ static int add_tpl_ref_mv(const AV1_COMMON *cm, const MACROBLOCKD *xd,
   return 1;
 }
 
-static AOM_INLINE void process_compound_ref_mv_candidate(
+static inline void process_compound_ref_mv_candidate(
     const MB_MODE_INFO *const candidate, const AV1_COMMON *const cm,
     const MV_REFERENCE_FRAME *const rf, int_mv ref_id[2][2],
     int ref_id_count[2], int_mv ref_diff[2][2], int ref_diff_count[2]) {
@@ -440,7 +445,7 @@ static AOM_INLINE void process_compound_ref_mv_candidate(
   }
 }
 
-static AOM_INLINE void process_single_ref_mv_candidate(
+static inline void process_single_ref_mv_candidate(
     const MB_MODE_INFO *const candidate, const AV1_COMMON *const cm,
     MV_REFERENCE_FRAME ref_frame, uint8_t *const refmv_count,
     CANDIDATE_MV ref_mv_stack[MAX_REF_MV_STACK_SIZE],
@@ -471,7 +476,7 @@ static AOM_INLINE void process_single_ref_mv_candidate(
   }
 }
 
-static AOM_INLINE void setup_ref_mv_list(
+static inline void setup_ref_mv_list(
     const AV1_COMMON *cm, const MACROBLOCKD *xd, MV_REFERENCE_FRAME ref_frame,
     uint8_t *const refmv_count,
     CANDIDATE_MV ref_mv_stack[MAX_REF_MV_STACK_SIZE],
@@ -839,6 +844,8 @@ void av1_setup_frame_buf_refs(AV1_COMMON *cm) {
   cm->cur_frame->order_hint = cm->current_frame.order_hint;
   cm->cur_frame->display_order_hint = cm->current_frame.display_order_hint;
   cm->cur_frame->pyramid_level = cm->current_frame.pyramid_level;
+  cm->cur_frame->filter_level[0] = -1;
+  cm->cur_frame->filter_level[1] = -1;
   MV_REFERENCE_FRAME ref_frame;
   for (ref_frame = LAST_FRAME; ref_frame <= ALTREF_FRAME; ++ref_frame) {
     const RefCntBuffer *const buf = get_ref_frame_buf(cm, ref_frame);
@@ -960,8 +967,9 @@ static int motion_field_projection(AV1_COMMON *cm,
             abs(start_to_current_frame_offset) <= MAX_FRAME_DISTANCE;
 
         if (pos_valid) {
-          get_mv_projection(&this_mv.as_mv, fwd_mv,
-                            start_to_current_frame_offset, ref_frame_offset);
+          av1_get_mv_projection(&this_mv.as_mv, fwd_mv,
+                                start_to_current_frame_offset,
+                                ref_frame_offset);
           pos_valid = get_block_position(cm, &mi_r, &mi_c, blk_row, blk_col,
                                          this_mv.as_mv, dir >> 1);
         }
@@ -1065,7 +1073,7 @@ void av1_setup_motion_field(AV1_COMMON *cm) {
   if (ref_stamp >= 0) motion_field_projection(cm, LAST2_FRAME, 2);
 }
 
-static INLINE void record_samples(const MB_MODE_INFO *mbmi, int *pts,
+static inline void record_samples(const MB_MODE_INFO *mbmi, int *pts,
                                   int *pts_inref, int row_offset, int sign_r,
                                   int col_offset, int sign_c) {
   const int bw = block_size_wide[mbmi->bsize];
@@ -1327,8 +1335,8 @@ static int compare_ref_frame_info(const void *arg_a, const void *arg_b) {
   return info_a->map_idx - info_b->map_idx;
 }
 
-static AOM_INLINE void set_ref_frame_info(int *remapped_ref_idx, int frame_idx,
-                                          REF_FRAME_INFO *ref_info) {
+static inline void set_ref_frame_info(int *remapped_ref_idx, int frame_idx,
+                                      REF_FRAME_INFO *ref_info) {
   assert(frame_idx >= 0 && frame_idx < INTER_REFS_PER_FRAME);
 
   remapped_ref_idx[frame_idx] = ref_info->map_idx;
