@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2017, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -13,14 +13,16 @@
 
 #include "config/av1_rtcd.h"
 
+#if CONFIG_SVT_AV1
 #include "third_party/SVT-AV1/convolve_avx2.h"
+#endif
 
 #include "aom_dsp/aom_dsp_common.h"
 #include "aom_dsp/x86/convolve_avx2.h"
 #include "aom_dsp/x86/convolve_common_intrin.h"
 #include "aom_dsp/x86/synonyms.h"
 
-static AOM_INLINE void av1_convolve_y_sr_general_avx2(
+static inline void av1_convolve_y_sr_general_avx2(
     const uint8_t *src, int src_stride, uint8_t *dst, int dst_stride, int w,
     int h, const InterpFilterParams *filter_params_y, const int subpel_y_qn) {
   // right shift is F-1 because we are already dividing
@@ -512,19 +514,24 @@ void av1_convolve_y_sr_avx2(const uint8_t *src, int32_t src_stride,
                             uint8_t *dst, int32_t dst_stride, int32_t w,
                             int32_t h,
                             const InterpFilterParams *filter_params_y,
-                            const int32_t subpel_y_q4) {
-  const int vert_tap = get_filter_tap(filter_params_y, subpel_y_q4);
+                            const int32_t subpel_y_qn) {
+#if CONFIG_SVT_AV1
+  const int vert_tap = get_filter_tap(filter_params_y, subpel_y_qn);
 
   if (vert_tap == 12) {
     av1_convolve_y_sr_general_avx2(src, src_stride, dst, dst_stride, w, h,
-                                   filter_params_y, subpel_y_q4);
+                                   filter_params_y, subpel_y_qn);
   } else {
     av1_convolve_y_sr_specialized_avx2(src, src_stride, dst, dst_stride, w, h,
-                                       filter_params_y, subpel_y_q4);
+                                       filter_params_y, subpel_y_qn);
   }
+#else
+  av1_convolve_y_sr_general_avx2(src, src_stride, dst, dst_stride, w, h,
+                                 filter_params_y, subpel_y_qn);
+#endif
 }
 
-static AOM_INLINE void av1_convolve_x_sr_general_avx2(
+static inline void av1_convolve_x_sr_general_avx2(
     const uint8_t *src, int src_stride, uint8_t *dst, int dst_stride, int w,
     int h, const InterpFilterParams *filter_params_x, const int subpel_x_qn,
     ConvolveParams *conv_params) {
@@ -901,16 +908,21 @@ void av1_convolve_x_sr_avx2(const uint8_t *src, int32_t src_stride,
                             uint8_t *dst, int32_t dst_stride, int32_t w,
                             int32_t h,
                             const InterpFilterParams *filter_params_x,
-                            const int32_t subpel_x_q4,
+                            const int32_t subpel_x_qn,
                             ConvolveParams *conv_params) {
-  const int horz_tap = get_filter_tap(filter_params_x, subpel_x_q4);
+#if CONFIG_SVT_AV1
+  const int horz_tap = get_filter_tap(filter_params_x, subpel_x_qn);
 
   if (horz_tap == 12) {
     av1_convolve_x_sr_general_avx2(src, src_stride, dst, dst_stride, w, h,
-                                   filter_params_x, subpel_x_q4, conv_params);
+                                   filter_params_x, subpel_x_qn, conv_params);
   } else {
     av1_convolve_x_sr_specialized_avx2(src, src_stride, dst, dst_stride, w, h,
-                                       filter_params_x, subpel_x_q4,
+                                       filter_params_x, subpel_x_qn,
                                        conv_params);
   }
+#else
+  av1_convolve_x_sr_general_avx2(src, src_stride, dst, dst_stride, w, h,
+                                 filter_params_x, subpel_x_qn, conv_params);
+#endif
 }
