@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2021, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -20,6 +20,8 @@
 #include "av1/encoder/block.h"
 #include "av1/encoder/encoder.h"
 
+#define MB_WIENER_MT_UNIT_SIZE BLOCK_64X64
+
 void av1_init_mb_wiener_var_buffer(AV1_COMP *cpi);
 
 void av1_calc_mb_wiener_var_row(AV1_COMP *const cpi, MACROBLOCK *x,
@@ -31,14 +33,19 @@ void av1_calc_mb_wiener_var_row(AV1_COMP *const cpi, MACROBLOCK *x,
 
 void av1_set_mb_wiener_variance(AV1_COMP *cpi);
 
-int av1_get_sbq_perceptual_ai(AV1_COMP *const cpi, BLOCK_SIZE bsize, int mi_row,
-                              int mi_col);
+int av1_get_sbq_perceptual_ai(const AV1_COMP *const cpi, BLOCK_SIZE bsize,
+                              int mi_row, int mi_col);
 
 // User rating based mode
 void av1_init_mb_ur_var_buffer(AV1_COMP *cpi);
 
 void av1_set_mb_ur_variance(AV1_COMP *cpi);
 
-int av1_get_sbq_user_rating_based(AV1_COMP *const cpi, int mi_row, int mi_col);
+int av1_get_sbq_user_rating_based(const AV1_COMP *const cpi, int mi_row,
+                                  int mi_col);
+
+#if !CONFIG_REALTIME_ONLY
+int av1_get_sbq_variance_boost(const AV1_COMP *const cpi, const MACROBLOCK *x);
+#endif
 
 #endif  // AOM_AV1_ENCODER_ALLINTRA_VIS_H_
