@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -13,8 +13,10 @@
 
 #include "config/aom_dsp_rtcd.h"
 
+#include "aom/aomcx.h"
 #include "aom_dsp/quantize.h"
 #include "aom_mem/aom_mem.h"
+#include "aom_ports/bitops.h"
 #include "aom_ports/mem.h"
 
 #include "av1/common/idct.h"
@@ -513,7 +515,7 @@ void av1_highbd_quantize_b_facade(const tran_low_t *coeff_ptr,
   }
 }
 
-static INLINE void highbd_quantize_dc(
+static inline void highbd_quantize_dc(
     const tran_low_t *coeff_ptr, int n_coeffs, int skip_block,
     const int16_t *round_ptr, const int16_t quant, tran_low_t *qcoeff_ptr,
     tran_low_t *dqcoeff_ptr, const int16_t dequant_ptr, uint16_t *eob_ptr,
@@ -581,7 +583,7 @@ static void invert_quant(int16_t *quant, int16_t *shift, int d) {
   uint32_t t;
   int l, m;
   t = d;
-  for (l = 0; t > 1; l++) t >>= 1;
+  l = get_msb(t);
   m = 1 + (1 << (16 + l)) / d;
   *quant = (int16_t)(m - (1 << 16));
   *shift = 1 << (16 - l);
@@ -602,15 +604,22 @@ static int get_qzbin_factor(int q, aom_bit_depth_t bit_depth) {
 void av1_build_quantizer(aom_bit_depth_t bit_depth, int y_dc_delta_q,
                          int u_dc_delta_q, int u_ac_delta_q, int v_dc_delta_q,
                          int v_ac_delta_q, QUANTS *const quants,
-                         Dequants *const deq) {
+                         Dequants *const deq, int sharpness) {
   int i, q, quant_QTX;
+  const int sharpness_adjustment = 16 * (7 - sharpness) / 7;
 
   for (q = 0; q < QINDEX_RANGE; q++) {
     const int qzbin_factor = get_qzbin_factor(q, bit_depth);
-    const int qrounding_factor = q == 0 ? 64 : 48;
+    int qrounding_factor = q == 0 ? 64 : 48;
 
     for (i = 0; i < 2; ++i) {
-      const int qrounding_factor_fp = 64;
+      int qrounding_factor_fp = 64;
+
+      if (sharpness != 0 && q != 0) {
+        qrounding_factor = 64 - sharpness_adjustment;
+        qrounding_factor_fp = 64 - sharpness_adjustment;
+      }
+
       // y quantizer with TX scale
       quant_QTX = i == 0 ? av1_dc_quant_QTX(q, y_dc_delta_q, bit_depth)
                          : av1_ac_quant_QTX(q, 0, bit_depth);
@@ -673,21 +682,23 @@ void av1_build_quantizer(aom_bit_depth_t bit_depth, int y_dc_delta_q,
   }
 }
 
-static INLINE bool deltaq_params_have_changed(
+static inline bool deltaq_params_have_changed(
     const DeltaQuantParams *prev_deltaq_params,
     const CommonQuantParams *quant_params) {
   return (prev_deltaq_params->y_dc_delta_q != quant_params->y_dc_delta_q ||
           prev_deltaq_params->u_dc_delta_q != quant_params->u_dc_delta_q ||
           prev_deltaq_params->v_dc_delta_q != quant_params->v_dc_delta_q ||
           prev_deltaq_params->u_ac_delta_q != quant_params->u_ac_delta_q ||
-          prev_deltaq_params->v_ac_delta_q != quant_params->v_ac_delta_q);
+          prev_deltaq_params->v_ac_delta_q != quant_params->v_ac_delta_q ||
+          prev_deltaq_params->sharpness != quant_params->sharpness);
 }
 
 void av1_init_quantizer(EncQuantDequantParams *const enc_quant_dequant_params,
-                        const CommonQuantParams *quant_params,
-                        aom_bit_depth_t bit_depth) {
+                        CommonQuantParams *quant_params,
+                        aom_bit_depth_t bit_depth, int sharpness) {
   DeltaQuantParams *const prev_deltaq_params =
       &enc_quant_dequant_params->prev_deltaq_params;
+  quant_params->sharpness = sharpness;
 
   // Re-initialize the quantizer only if any of the dc/ac deltaq parameters
   // change.
@@ -697,7 +708,7 @@ void av1_init_quantizer(EncQuantDequantParams *const enc_quant_dequant_params,
   av1_build_quantizer(bit_depth, quant_params->y_dc_delta_q,
                       quant_params->u_dc_delta_q, quant_params->u_ac_delta_q,
                       quant_params->v_dc_delta_q, quant_params->v_ac_delta_q,
-                      quants, dequants);
+                      quants, dequants, sharpness);
 
   // Record the state of deltaq parameters.
   prev_deltaq_params->y_dc_delta_q = quant_params->y_dc_delta_q;
@@ -705,10 +716,21 @@ void av1_init_quantizer(EncQuantDequantParams *const enc_quant_dequant_params,
   prev_deltaq_params->v_dc_delta_q = quant_params->v_dc_delta_q;
   prev_deltaq_params->u_ac_delta_q = quant_params->u_ac_delta_q;
   prev_deltaq_params->v_ac_delta_q = quant_params->v_ac_delta_q;
+  prev_deltaq_params->sharpness = sharpness;
 }
 
-void av1_set_q_index(const EncQuantDequantParams *enc_quant_dequant_params,
-                     int qindex, MACROBLOCK *x) {
+/*!\brief Update quantize parameters in MACROBLOCK
+ *
+ * \param[in]  enc_quant_dequant_params This parameter cached the quantize and
+ *                                      dequantize parameters for all q
+ *                                      indices.
+ * \param[in]  qindex                   Quantize index used for the current
+ *                                      superblock.
+ * \param[out] x                        A superblock data structure for
+ *                                      encoder.
+ */
+static void set_q_index(const EncQuantDequantParams *enc_quant_dequant_params,
+                        int qindex, MACROBLOCK *x) {
   const QUANTS *const quants = &enc_quant_dequant_params->quants;
   const Dequants *const dequants = &enc_quant_dequant_params->dequants;
   x->qindex = qindex;
@@ -743,8 +765,15 @@ void av1_set_q_index(const EncQuantDequantParams *enc_quant_dequant_params,
   x->plane[2].dequant_QTX = dequants->v_dequant_QTX[qindex];
 }
 
-void av1_set_qmatrix(const CommonQuantParams *quant_params, int segment_id,
-                     MACROBLOCKD *xd) {
+/*!\brief Update quantize matrix in MACROBLOCKD based on segment id
+ *
+ * \param[in]  quant_params  Quantize parameters used by encoder and decoder
+ * \param[in]  segment_id    Segment id.
+ * \param[out] xd            A superblock data structure used by encoder and
+ * decoder.
+ */
+static void set_qmatrix(const CommonQuantParams *quant_params, int segment_id,
+                        MACROBLOCKD *xd) {
   const int use_qmatrix = av1_use_qmatrix(quant_params, xd, segment_id);
   const int qmlevel_y =
       use_qmatrix ? quant_params->qmatrix_level_y : NUM_QM_LEVELS - 1;
@@ -774,19 +803,19 @@ void av1_init_plane_quantizers(const AV1_COMP *cpi, MACROBLOCK *x,
   const FRAME_TYPE frame_type = cm->current_frame.frame_type;
   int qindex_rd;
 
-  const int current_qindex = AOMMAX(
-      0,
-      AOMMIN(QINDEX_RANGE - 1, cm->delta_q_info.delta_q_present_flag
-                                   ? quant_params->base_qindex + x->delta_qindex
-                                   : quant_params->base_qindex));
+  const int current_qindex =
+      clamp(cm->delta_q_info.delta_q_present_flag
+                ? quant_params->base_qindex + x->delta_qindex
+                : quant_params->base_qindex,
+            0, QINDEX_RANGE - 1);
   const int qindex = av1_get_qindex(&cm->seg, segment_id, current_qindex);
 
   if (cpi->oxcf.sb_qp_sweep) {
     const int current_rd_qindex =
-        AOMMAX(0, AOMMIN(QINDEX_RANGE - 1, cm->delta_q_info.delta_q_present_flag
-                                               ? quant_params->base_qindex +
-                                                     x->rdmult_delta_qindex
-                                               : quant_params->base_qindex));
+        clamp(cm->delta_q_info.delta_q_present_flag
+                  ? quant_params->base_qindex + x->rdmult_delta_qindex
+                  : quant_params->base_qindex,
+              0, QINDEX_RANGE - 1);
     qindex_rd = av1_get_qindex(&cm->seg, segment_id, current_rd_qindex);
   } else {
     qindex_rd = qindex;
@@ -797,17 +826,17 @@ void av1_init_plane_quantizers(const AV1_COMP *cpi, MACROBLOCK *x,
       qindex_rdmult, cm->seq_params->bit_depth,
       cpi->ppi->gf_group.update_type[cpi->gf_frame_index], layer_depth,
       boost_index, frame_type, cpi->oxcf.q_cfg.use_fixed_qp_offsets,
-      is_stat_consumption_stage(cpi));
+      is_stat_consumption_stage(cpi), cpi->oxcf.tune_cfg.tuning);
 
   const int qindex_change = x->qindex != qindex;
   if (qindex_change || do_update) {
-    av1_set_q_index(&cpi->enc_quant_dequant_params, qindex, x);
+    set_q_index(&cpi->enc_quant_dequant_params, qindex, x);
   }
 
   MACROBLOCKD *const xd = &x->e_mbd;
   if ((segment_id != x->prev_segment_id) ||
       av1_use_qmatrix(quant_params, xd, segment_id)) {
-    av1_set_qmatrix(quant_params, segment_id, xd);
+    set_qmatrix(quant_params, segment_id, xd);
   }
 
   x->seg_skip_block = segfeature_active(&cm->seg, segment_id, SEG_LVL_SKIP);
@@ -846,19 +875,87 @@ static int adjust_hdr_cr_deltaq(int base_qindex) {
 }
 
 void av1_set_quantizer(AV1_COMMON *const cm, int min_qmlevel, int max_qmlevel,
-                       int q, int enable_chroma_deltaq, int enable_hdr_deltaq) {
+                       int q, int enable_chroma_deltaq, int enable_hdr_deltaq,
+                       bool is_allintra, aom_tune_metric tuning) {
   // quantizer has to be reinitialized with av1_init_quantizer() if any
   // delta_q changes.
   CommonQuantParams *quant_params = &cm->quant_params;
   quant_params->base_qindex = AOMMAX(cm->delta_q_info.delta_q_present_flag, q);
   quant_params->y_dc_delta_q = 0;
 
-  if (enable_chroma_deltaq) {
-    // TODO(aomedia:2717): need to design better delta
-    quant_params->u_dc_delta_q = 2;
-    quant_params->u_ac_delta_q = 2;
-    quant_params->v_dc_delta_q = 2;
-    quant_params->v_ac_delta_q = 2;
+  // Disable deltaq in lossless mode.
+  if (enable_chroma_deltaq && q) {
+    if (is_allintra &&
+        (tuning == AOM_TUNE_IQ || tuning == AOM_TUNE_SSIMULACRA2)) {
+      int chroma_dc_delta_q = 0;
+      int chroma_ac_delta_q = 0;
+
+      if (cm->seq_params->subsampling_x == 1 &&
+          cm->seq_params->subsampling_y == 1) {
+        // 4:2:0 subsampling: Constant chroma delta_q decrease (i.e. improved
+        // chroma quality relative to luma) with gradual ramp-down for very low
+        // qindexes.
+        // Lowering chroma delta_q by 16 was found to improve SSIMULACRA 2
+        // BD-Rate by 1.5-2% on Daala's subset1, as well as reducing chroma
+        // artifacts (smudging, discoloration) during subjective quality
+        // evaluations.
+        // The ramp-down of chroma increase was determined by generating the
+        // convex hull of SSIMULACRA 2 scores (for all boosts from 0-16), and
+        // finding a linear equation that fits the convex hull.
+        chroma_dc_delta_q = -clamp((quant_params->base_qindex / 2) - 14, 0, 16);
+        chroma_ac_delta_q = chroma_dc_delta_q;
+      } else if (cm->seq_params->subsampling_x == 1 &&
+                 cm->seq_params->subsampling_y == 0) {
+        // 4:2:2 subsampling: Constant chroma AC delta_q increase (i.e. improved
+        // luma quality relative to chroma) with gradual ramp-down for very low
+        // qindexes.
+        // SSIMULACRA 2 appears to have some issues correctly scoring 4:2:2
+        // material. Solely optimizing for maximum scores suggests a chroma AC
+        // delta_q of 12 is the most efficient. However, visual inspection on
+        // difficult-to-encode material resulted in chroma quality degrading too
+        // much relative to luma, and chroma channels ending up being too small
+        // compared to equivalent 4:4:4 or 4:2:0 encodes.
+        // A chroma AC delta_q of 6 was selected because encoded chroma channels
+        // have a much closer size to 4:4:4 and 4:2:0 encodes, and have more
+        // favorable visual quality characteristics.
+        // The ramp-down of chroma decrease was put into place to match 4:2:0
+        // and 4:4:4 behavior. There were no special considerations on
+        // SSIMULACRA 2 scores.
+        chroma_dc_delta_q = 0;
+        chroma_ac_delta_q = clamp((quant_params->base_qindex / 2), 0, 6);
+      } else if (cm->seq_params->subsampling_x == 0 &&
+                 cm->seq_params->subsampling_y == 0) {
+        // 4:4:4 subsampling: Constant chroma AC delta_q increase (i.e. improved
+        // luma quality relative to chroma) with gradual ramp-down for very low
+        // qindexes.
+        // Raising chroma AC delta_q by 24 was found to improve SSIMULACRA 2
+        // BD-Rate by 2.5-3% on Daala's subset1, as well as providing a more
+        // balanced bit allocation between the (relatively-starved) luma and
+        // chroma channels.
+        // Raising chroma DC delta_q appears to be harmful, both for SSIMULACRA
+        // 2 scores and subjective quality (harshens blocking artifacts).
+        // The ramp-down of chroma decrease was put into place so (lossy) QP 0
+        // encodes still score within 0.1 SSIMULACRA 2 points of the equivalent
+        // with no chroma delta_q (with a small efficiency improvement), while
+        // encodes in the SSIMULACRA 2 <=90 range yield full benefits from this
+        // adjustment.
+        chroma_dc_delta_q = 0;
+        chroma_ac_delta_q = clamp((quant_params->base_qindex / 2), 0, 24);
+      }
+
+      // TODO: bug https://crbug.com/aomedia/375221136 - find chroma_delta_q
+      // values for 4:2:2 subsampling mode.
+      quant_params->u_dc_delta_q = chroma_dc_delta_q;
+      quant_params->u_ac_delta_q = chroma_ac_delta_q;
+      quant_params->v_dc_delta_q = chroma_dc_delta_q;
+      quant_params->v_ac_delta_q = chroma_ac_delta_q;
+    } else {
+      // TODO(aomedia:2717): need to design better delta
+      quant_params->u_dc_delta_q = 2;
+      quant_params->u_ac_delta_q = 2;
+      quant_params->v_dc_delta_q = 2;
+      quant_params->v_ac_delta_q = 2;
+    }
   } else {
     quant_params->u_dc_delta_q = 0;
     quant_params->u_ac_delta_q = 0;
@@ -868,7 +965,7 @@ void av1_set_quantizer(AV1_COMMON *const cm, int min_qmlevel, int max_qmlevel,
 
   // following section 8.3.2 in T-REC-H.Sup15 document
   // to apply to AV1 qindex in the range of [0, 255]
-  if (enable_hdr_deltaq) {
+  if (enable_hdr_deltaq && q) {
     int dqpCb = adjust_hdr_cb_deltaq(quant_params->base_qindex);
     int dqpCr = adjust_hdr_cr_deltaq(quant_params->base_qindex);
     quant_params->u_dc_delta_q = quant_params->u_ac_delta_q = dqpCb;
@@ -878,18 +975,53 @@ void av1_set_quantizer(AV1_COMMON *const cm, int min_qmlevel, int max_qmlevel,
     }
   }
 
-  quant_params->qmatrix_level_y =
-      aom_get_qmlevel(quant_params->base_qindex, min_qmlevel, max_qmlevel);
-  quant_params->qmatrix_level_u =
-      aom_get_qmlevel(quant_params->base_qindex + quant_params->u_ac_delta_q,
-                      min_qmlevel, max_qmlevel);
+  // Select the best luma and chroma QM formulas based on encoding mode and
+  // tuning
+  int (*get_luma_qmlevel)(int, int, int);
+  int (*get_chroma_qmlevel)(int, int, int);
 
-  if (!cm->seq_params->separate_uv_delta_q)
+  if (is_allintra) {
+    if (tuning == AOM_TUNE_IQ || tuning == AOM_TUNE_SSIMULACRA2) {
+      if (tuning == AOM_TUNE_SSIMULACRA2) {
+        // Use luma QM formula specifically tailored for tune SSIMULACRA2
+        get_luma_qmlevel = aom_get_qmlevel_luma_ssimulacra2;
+      } else {
+        get_luma_qmlevel = aom_get_qmlevel_allintra;
+      }
+
+      if (cm->seq_params->subsampling_x == 0 &&
+          cm->seq_params->subsampling_y == 0) {
+        // 4:4:4 subsampling mode has 4x the number of chroma coefficients
+        // compared to 4:2:0 (2x on each dimension). This means the encoder
+        // should use lower chroma QM levels that more closely match the scaling
+        // of an equivalent 4:2:0 chroma QM.
+        get_chroma_qmlevel = aom_get_qmlevel_444_chroma;
+      } else {
+        // For all other chroma subsampling modes, use the all intra QM formula
+        get_chroma_qmlevel = aom_get_qmlevel_allintra;
+      }
+    } else {
+      get_luma_qmlevel = aom_get_qmlevel_allintra;
+      get_chroma_qmlevel = aom_get_qmlevel_allintra;
+    }
+  } else {
+    get_luma_qmlevel = aom_get_qmlevel;
+    get_chroma_qmlevel = aom_get_qmlevel;
+  }
+
+  quant_params->qmatrix_level_y =
+      get_luma_qmlevel(quant_params->base_qindex, min_qmlevel, max_qmlevel);
+  quant_params->qmatrix_level_u =
+      get_chroma_qmlevel(quant_params->base_qindex + quant_params->u_ac_delta_q,
+                         min_qmlevel, max_qmlevel);
+
+  if (cm->seq_params->separate_uv_delta_q) {
+    quant_params->qmatrix_level_v = get_chroma_qmlevel(
+        quant_params->base_qindex + quant_params->v_ac_delta_q, min_qmlevel,
+        max_qmlevel);
+  } else {
     quant_params->qmatrix_level_v = quant_params->qmatrix_level_u;
-  else
-    quant_params->qmatrix_level_v =
-        aom_get_qmlevel(quant_params->base_qindex + quant_params->v_ac_delta_q,
-                        min_qmlevel, max_qmlevel);
+  }
 }
 
 // Table that converts 0-63 Q-range values passed in outside to the Qindex
