@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2020, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -25,14 +25,14 @@
 extern "C" {
 #endif
 
-static AOM_INLINE void dealloc_context_buffers_ext(
+static inline void dealloc_context_buffers_ext(
     MBMIExtFrameBufferInfo *mbmi_ext_info) {
   aom_free(mbmi_ext_info->frame_base);
   mbmi_ext_info->frame_base = NULL;
   mbmi_ext_info->alloc_size = 0;
 }
 
-static AOM_INLINE void alloc_context_buffers_ext(
+static inline void alloc_context_buffers_ext(
     AV1_COMMON *cm, MBMIExtFrameBufferInfo *mbmi_ext_info) {
   const CommonModeInfoParams *const mi_params = &cm->mi_params;
 
@@ -55,7 +55,7 @@ static AOM_INLINE void alloc_context_buffers_ext(
   mbmi_ext_info->stride = mi_alloc_cols;
 }
 
-static AOM_INLINE void alloc_compressor_data(AV1_COMP *cpi) {
+static inline void alloc_compressor_data(AV1_COMP *cpi) {
   AV1_COMMON *cm = &cpi->common;
   CommonModeInfoParams *const mi_params = &cm->mi_params;
 
@@ -77,7 +77,10 @@ static AOM_INLINE void alloc_compressor_data(AV1_COMP *cpi) {
 
   av1_setup_shared_coeff_buffer(cm->seq_params, &cpi->td.shared_coeff_buf,
                                 cm->error);
-  av1_setup_sms_tree(cpi, &cpi->td);
+  if (av1_setup_sms_tree(cpi, &cpi->td)) {
+    aom_internal_error(cm->error, AOM_CODEC_MEM_ERROR,
+                       "Failed to allocate SMS tree");
+  }
   cpi->td.firstpass_ctx =
       av1_alloc_pmc(cpi, BLOCK_16X16, &cpi->td.shared_coeff_buf);
   if (!cpi->td.firstpass_ctx)
@@ -87,7 +90,7 @@ static AOM_INLINE void alloc_compressor_data(AV1_COMP *cpi) {
 
 // Allocate mbmi buffers which are used to store mode information at block
 // level.
-static AOM_INLINE void alloc_mb_mode_info_buffers(AV1_COMP *const cpi) {
+static inline void alloc_mb_mode_info_buffers(AV1_COMP *const cpi) {
   AV1_COMMON *const cm = &cpi->common;
   if (av1_alloc_context_buffers(cm, cm->width, cm->height,
                                 cpi->sf.part_sf.default_min_partition_size)) {
@@ -99,7 +102,7 @@ static AOM_INLINE void alloc_mb_mode_info_buffers(AV1_COMP *const cpi) {
     alloc_context_buffers_ext(cm, &cpi->mbmi_ext_info);
 }
 
-static AOM_INLINE void realloc_segmentation_maps(AV1_COMP *cpi) {
+static inline void realloc_segmentation_maps(AV1_COMP *cpi) {
   AV1_COMMON *const cm = &cpi->common;
   CommonModeInfoParams *const mi_params = &cm->mi_params;
 
@@ -120,8 +123,8 @@ static AOM_INLINE void realloc_segmentation_maps(AV1_COMP *cpi) {
                   aom_calloc(mi_params->mi_rows * mi_params->mi_cols, 1));
 }
 
-static AOM_INLINE void alloc_obmc_buffers(
-    OBMCBuffer *obmc_buffer, struct aom_internal_error_info *error) {
+static inline void alloc_obmc_buffers(OBMCBuffer *obmc_buffer,
+                                      struct aom_internal_error_info *error) {
   AOM_CHECK_MEM_ERROR(
       error, obmc_buffer->wsrc,
       (int32_t *)aom_memalign(16, MAX_SB_SQUARE * sizeof(*obmc_buffer->wsrc)));
@@ -138,7 +141,7 @@ static AOM_INLINE void alloc_obmc_buffers(
           16, MAX_MB_PLANE * MAX_SB_SQUARE * sizeof(*obmc_buffer->left_pred)));
 }
 
-static AOM_INLINE void release_obmc_buffers(OBMCBuffer *obmc_buffer) {
+static inline void release_obmc_buffers(OBMCBuffer *obmc_buffer) {
   aom_free(obmc_buffer->mask);
   aom_free(obmc_buffer->above_pred);
   aom_free(obmc_buffer->left_pred);
@@ -150,7 +153,7 @@ static AOM_INLINE void release_obmc_buffers(OBMCBuffer *obmc_buffer) {
   obmc_buffer->wsrc = NULL;
 }
 
-static AOM_INLINE void alloc_compound_type_rd_buffers(
+static inline void alloc_compound_type_rd_buffers(
     struct aom_internal_error_info *error, CompoundTypeRdBuffers *const bufs) {
   AOM_CHECK_MEM_ERROR(
       error, bufs->pred0,
@@ -169,7 +172,7 @@ static AOM_INLINE void alloc_compound_type_rd_buffers(
                                             sizeof(*bufs->tmp_best_mask_buf)));
 }
 
-static AOM_INLINE void release_compound_type_rd_buffers(
+static inline void release_compound_type_rd_buffers(
     CompoundTypeRdBuffers *const bufs) {
   aom_free(bufs->pred0);
   aom_free(bufs->pred1);
@@ -179,14 +182,18 @@ static AOM_INLINE void release_compound_type_rd_buffers(
   av1_zero(*bufs);  // Set all pointers to NULL for safety.
 }
 
-static AOM_INLINE void dealloc_compressor_data(AV1_COMP *cpi) {
+static inline void dealloc_compressor_data(AV1_COMP *cpi) {
   AV1_COMMON *const cm = &cpi->common;
   TokenInfo *token_info = &cpi->token_info;
+  AV1EncRowMultiThreadInfo *const enc_row_mt = &cpi->mt_info.enc_row_mt;
   const int num_planes = av1_num_planes(cm);
   dealloc_context_buffers_ext(&cpi->mbmi_ext_info);
 
   aom_free(cpi->tile_data);
   cpi->tile_data = NULL;
+  cpi->allocated_tiles = 0;
+  enc_row_mt->allocated_tile_cols = 0;
+  enc_row_mt->allocated_tile_rows = 0;
 
   // Delete sementation map
   aom_free(cpi->enc_seg.map);
@@ -198,6 +205,9 @@ static AOM_INLINE void dealloc_compressor_data(AV1_COMP *cpi) {
   aom_free(cpi->active_map.map);
   cpi->active_map.map = NULL;
 
+  aom_free(cpi->roi.roi_map);
+  cpi->roi.roi_map = NULL;
+
   aom_free(cpi->ssim_rdmult_scaling_factors);
   cpi->ssim_rdmult_scaling_factors = NULL;
 
@@ -244,11 +254,10 @@ static AOM_INLINE void dealloc_compressor_data(AV1_COMP *cpi) {
                              cpi->sf.part_sf.partition_search_type);
   cpi->td.pc_root = NULL;
 
-  for (int i = 0; i < 2; i++)
-    for (int j = 0; j < 2; j++) {
-      aom_free(cpi->td.mb.intrabc_hash_info.hash_value_buffer[i][j]);
-      cpi->td.mb.intrabc_hash_info.hash_value_buffer[i][j] = NULL;
-    }
+  for (int i = 0; i < 2; i++) {
+    aom_free(cpi->td.mb.intrabc_hash_info.hash_value_buffer[i]);
+    cpi->td.mb.intrabc_hash_info.hash_value_buffer[i] = NULL;
+  }
 
   av1_hash_table_destroy(&cpi->td.mb.intrabc_hash_info.intrabc_hash_table);
 
@@ -331,17 +340,19 @@ static AOM_INLINE void dealloc_compressor_data(AV1_COMP *cpi) {
     aom_free(cpi->td.mb.tmp_pred_bufs[j]);
   }
 
-#if CONFIG_DENOISE
+#if CONFIG_DENOISE && !CONFIG_REALTIME_ONLY
   if (cpi->denoise_and_model) {
     aom_denoise_and_model_free(cpi->denoise_and_model);
     cpi->denoise_and_model = NULL;
   }
 #endif
+#if !CONFIG_REALTIME_ONLY
   if (cpi->film_grain_table) {
     aom_film_grain_table_free(cpi->film_grain_table);
     aom_free(cpi->film_grain_table);
     cpi->film_grain_table = NULL;
   }
+#endif
 
   if (cpi->ppi->use_svc) av1_free_svc_cyclic_refresh(cpi);
   aom_free(cpi->svc.layer_context);
@@ -369,7 +380,7 @@ static AOM_INLINE void dealloc_compressor_data(AV1_COMP *cpi) {
   cpi->mb_delta_q = NULL;
 }
 
-static AOM_INLINE void allocate_gradient_info_for_hog(AV1_COMP *cpi) {
+static inline void allocate_gradient_info_for_hog(AV1_COMP *cpi) {
   if (!is_gradient_caching_for_hog_enabled(cpi)) return;
 
   PixelLevelGradientInfo *pixel_gradient_info = cpi->td.pixel_gradient_info;
@@ -385,7 +396,7 @@ static AOM_INLINE void allocate_gradient_info_for_hog(AV1_COMP *cpi) {
   cpi->td.mb.pixel_gradient_info = pixel_gradient_info;
 }
 
-static AOM_INLINE void allocate_src_var_of_4x4_sub_block_buf(AV1_COMP *cpi) {
+static inline void allocate_src_var_of_4x4_sub_block_buf(AV1_COMP *cpi) {
   if (!is_src_var_for_4x4_sub_blocks_caching_enabled(cpi)) return;
 
   Block4x4VarInfo *source_variance_info =
@@ -402,7 +413,7 @@ static AOM_INLINE void allocate_src_var_of_4x4_sub_block_buf(AV1_COMP *cpi) {
   cpi->td.mb.src_var_info_of_4x4_sub_blocks = source_variance_info;
 }
 
-static AOM_INLINE void variance_partition_alloc(AV1_COMP *cpi) {
+static inline void variance_partition_alloc(AV1_COMP *cpi) {
   AV1_COMMON *const cm = &cpi->common;
   const int num_64x64_blocks = (cm->seq_params->sb_size == BLOCK_64X64) ? 1 : 4;
   if (cpi->td.vt64x64) {
@@ -418,8 +429,9 @@ static AOM_INLINE void variance_partition_alloc(AV1_COMP *cpi) {
   }
 }
 
-static AOM_INLINE YV12_BUFFER_CONFIG *realloc_and_scale_source(
-    AV1_COMP *cpi, int scaled_width, int scaled_height) {
+static inline YV12_BUFFER_CONFIG *realloc_and_scale_source(AV1_COMP *cpi,
+                                                           int scaled_width,
+                                                           int scaled_height) {
   AV1_COMMON *cm = &cpi->common;
   const int num_planes = av1_num_planes(cm);
 
@@ -432,8 +444,7 @@ static AOM_INLINE YV12_BUFFER_CONFIG *realloc_and_scale_source(
           &cpi->scaled_source, scaled_width, scaled_height,
           cm->seq_params->subsampling_x, cm->seq_params->subsampling_y,
           cm->seq_params->use_highbitdepth, AOM_BORDER_IN_PIXELS,
-          cm->features.byte_alignment, NULL, NULL, NULL,
-          cpi->image_pyramid_levels, 0))
+          cm->features.byte_alignment, NULL, NULL, NULL, cpi->alloc_pyramid, 0))
     aom_internal_error(cm->error, AOM_CODEC_MEM_ERROR,
                        "Failed to reallocate scaled source buffer");
   assert(cpi->scaled_source.y_crop_width == scaled_width);
@@ -447,7 +458,7 @@ static AOM_INLINE YV12_BUFFER_CONFIG *realloc_and_scale_source(
 }
 
 // Deallocate allocated thread_data.
-static AOM_INLINE void free_thread_data(AV1_PRIMARY *ppi) {
+static inline void free_thread_data(AV1_PRIMARY *ppi) {
   PrimaryMultiThreadInfo *const p_mt_info = &ppi->p_mt_info;
   const int num_tf_workers =
       AOMMIN(p_mt_info->num_mod_workers[MOD_TF], p_mt_info->num_workers);
@@ -458,61 +469,60 @@ static AOM_INLINE void free_thread_data(AV1_PRIMARY *ppi) {
   for (int t = 1; t < p_mt_info->num_workers; ++t) {
     EncWorkerData *const thread_data = &p_mt_info->tile_thr_data[t];
     thread_data->td = thread_data->original_td;
-    aom_free(thread_data->td->tctx);
-    aom_free(thread_data->td->palette_buffer);
-    aom_free(thread_data->td->tmp_conv_dst);
-    release_compound_type_rd_buffers(&thread_data->td->comp_rd_buffer);
+    ThreadData *const td = thread_data->td;
+    if (!td) continue;
+    aom_free(td->tctx);
+    aom_free(td->palette_buffer);
+    aom_free(td->tmp_conv_dst);
+    release_compound_type_rd_buffers(&td->comp_rd_buffer);
     for (int j = 0; j < 2; ++j) {
-      aom_free(thread_data->td->tmp_pred_bufs[j]);
+      aom_free(td->tmp_pred_bufs[j]);
     }
-    aom_free(thread_data->td->pixel_gradient_info);
-    aom_free(thread_data->td->src_var_info_of_4x4_sub_blocks);
-    release_obmc_buffers(&thread_data->td->obmc_buffer);
-    aom_free(thread_data->td->vt64x64);
+    aom_free(td->pixel_gradient_info);
+    aom_free(td->src_var_info_of_4x4_sub_blocks);
+    release_obmc_buffers(&td->obmc_buffer);
+    aom_free(td->vt64x64);
 
     for (int x = 0; x < 2; x++) {
-      for (int y = 0; y < 2; y++) {
-        aom_free(thread_data->td->hash_value_buffer[x][y]);
-        thread_data->td->hash_value_buffer[x][y] = NULL;
-      }
+      aom_free(td->hash_value_buffer[x]);
+      td->hash_value_buffer[x] = NULL;
     }
-    aom_free(thread_data->td->mv_costs_alloc);
-    thread_data->td->mv_costs_alloc = NULL;
-    aom_free(thread_data->td->dv_costs_alloc);
-    thread_data->td->dv_costs_alloc = NULL;
-    aom_free(thread_data->td->counts);
-    av1_free_pmc(thread_data->td->firstpass_ctx, num_planes);
-    thread_data->td->firstpass_ctx = NULL;
-    av1_free_shared_coeff_buffer(&thread_data->td->shared_coeff_buf);
-    av1_free_sms_tree(thread_data->td);
+    aom_free(td->mv_costs_alloc);
+    td->mv_costs_alloc = NULL;
+    aom_free(td->dv_costs_alloc);
+    td->dv_costs_alloc = NULL;
+    aom_free(td->counts);
+    av1_free_pmc(td->firstpass_ctx, num_planes);
+    td->firstpass_ctx = NULL;
+    av1_free_shared_coeff_buffer(&td->shared_coeff_buf);
+    av1_free_sms_tree(td);
     // This call ensures that the buffers allocated by tf_alloc_and_reset_data()
     // in prepare_tf_workers() for MT encode are freed in case an error is
     // encountered during temporal filtering (due to early termination
     // tf_dealloc_thread_data() in av1_tf_do_filtering_mt() would not be
     // invoked).
-    if (t < num_tf_workers)
-      tf_dealloc_data(&thread_data->td->tf_data, is_highbitdepth);
+    if (t < num_tf_workers) tf_dealloc_data(&td->tf_data, is_highbitdepth);
     // This call ensures that tpl_tmp_buffers for MT encode are freed in case of
     // an error during tpl.
-    if (t < num_tpl_workers)
-      tpl_dealloc_temp_buffers(&thread_data->td->tpl_tmp_buffers);
+    if (t < num_tpl_workers) tpl_dealloc_temp_buffers(&td->tpl_tmp_buffers);
     // This call ensures that the buffers in gm_data for MT encode are freed in
     // case of an error during gm.
-    gm_dealloc_data(&thread_data->td->gm_data);
-    av1_dealloc_mb_data(&thread_data->td->mb, num_planes);
-    aom_free(thread_data->td->mb.sb_stats_cache);
-    thread_data->td->mb.sb_stats_cache = NULL;
-    aom_free(thread_data->td->mb.sb_fp_stats);
-    thread_data->td->mb.sb_fp_stats = NULL;
+    gm_dealloc_data(&td->gm_data);
+    av1_dealloc_mb_data(&td->mb, num_planes);
+    aom_free(td->mb.sb_stats_cache);
+    td->mb.sb_stats_cache = NULL;
+    aom_free(td->mb.sb_fp_stats);
+    td->mb.sb_fp_stats = NULL;
 #if CONFIG_PARTITION_SEARCH_ORDER
-    aom_free(thread_data->td->mb.rdcost);
-    thread_data->td->mb.rdcost = NULL;
+    aom_free(td->mb.rdcost);
+    td->mb.rdcost = NULL;
 #endif
-    av1_free_pc_tree_recursive(thread_data->td->pc_root, num_planes, 0, 0,
-                               SEARCH_PARTITION);
-    thread_data->td->pc_root = NULL;
-    av1_dealloc_mb_wiener_var_pred_buf(thread_data->td);
-    aom_free(thread_data->td);
+    av1_free_pc_tree_recursive(td->pc_root, num_planes, 0, 0, SEARCH_PARTITION);
+    td->pc_root = NULL;
+    av1_dealloc_mb_wiener_var_pred_buf(td);
+    aom_free(td);
+    thread_data->td = NULL;
+    thread_data->original_td = NULL;
   }
 }
 
