@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -12,29 +12,12 @@
 #ifndef AOM_AV1_ENCODER_HASH_H_
 #define AOM_AV1_ENCODER_HASH_H_
 
-#include "config/aom_config.h"
-
 #include "aom/aom_integer.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-typedef struct _crc_calculator {
-  uint32_t remainder;
-  uint32_t trunc_poly;
-  uint32_t bits;
-  uint32_t table[256];
-  uint32_t final_result_mask;
-} CRC_CALCULATOR;
-
-// Initialize the crc calculator. It must be executed at least once before
-// calling av1_get_crc_value().
-void av1_crc_calculator_init(CRC_CALCULATOR *p_crc_calculator, uint32_t bits,
-                             uint32_t truncPoly);
-uint32_t av1_get_crc_value(CRC_CALCULATOR *p_crc_calculator, uint8_t *p,
-                           int length);
-
 // CRC32C: POLY = 0x82f63b78;
 typedef struct _CRC32C {
   /* Table for a quadword-at-a-time software crc. */
@@ -44,6 +27,10 @@ typedef struct _CRC32C {
 // init table for software version crc32c
 void av1_crc32c_calculator_init(CRC32C *p_crc32c);
 
+// Maximum number of subblocks per block
+// The biggest intraBC block size supported by AV1 is 128x128, and the smallest
+// subblock size is 2x2, therefore there can be a maximum of (128/2) * (128/2)
+// subblocks per block: 64 * 64 = 4096
 #define AOM_BUFFER_SIZE_FOR_BLOCK_HASH (4096)
 
 #ifdef __cplusplus
