@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -14,6 +14,7 @@
 
 #include "av1/common/pred_common.h"
 
+#include "aom_ports/bitops.h"
 #include "av1/encoder/block.h"
 #include "av1/encoder/cost.h"
 #include "av1/encoder/encoder.h"
@@ -35,7 +36,19 @@ static int int16_comparer(const void *a, const void *b) {
   return (*(int16_t *)a - *(int16_t *)b);
 }
 
-int av1_remove_duplicates(int16_t *centroids, int num_centroids) {
+/*!\brief Removes duplicated centroid indices.
+ *
+ * \ingroup palette_mode_search
+ * \param[in]    centroids          A list of centroids index.
+ * \param[in]    num_centroids      Number of centroids.
+ *
+ * \return Returns the number of unique centroids and saves the unique centroids
+ * in beginning of the centroids array.
+ *
+ * \attention The centroids should be rounded to integers before calling this
+ * method.
+ */
+static int remove_duplicates(int16_t *centroids, int num_centroids) {
   int num_unique;  // number of unique centroids
   int i;
   qsort(centroids, num_centroids, sizeof(*centroids), int16_comparer);
@@ -64,13 +77,13 @@ static int delta_encode_cost(const int *colors, int num, int bit_depth,
     assert(delta >= min_val);
     if (delta > max_delta) max_delta = delta;
   }
-  int bits_per_delta = AOMMAX(av1_ceil_log2(max_delta + 1 - min_val), min_bits);
+  int bits_per_delta = AOMMAX(aom_ceil_log2(max_delta + 1 - min_val), min_bits);
   assert(bits_per_delta <= bit_depth);
   int range = (1 << bit_depth) - colors[0] - min_val;
   for (int i = 0; i < num - 1; ++i) {
     bits_cost += bits_per_delta;
     range -= deltas[i];
-    bits_per_delta = AOMMIN(bits_per_delta, av1_ceil_log2(range));
+    bits_per_delta = AOMMIN(bits_per_delta, aom_ceil_log2(range));
   }
   return bits_cost;
 }
@@ -119,7 +132,7 @@ int av1_get_palette_delta_bits_v(const PALETTE_MODE_INFO *const pmi,
     if (d > max_d) max_d = d;
     if (d == 0) ++(*zero_count);
   }
-  return AOMMAX(av1_ceil_log2(max_d + 1), *min_bits);
+  return AOMMAX(aom_ceil_log2(max_d + 1), *min_bits);
 }
 
 int av1_palette_color_cost_y(const PALETTE_MODE_INFO *const pmi,
@@ -164,9 +177,9 @@ int av1_palette_color_cost_uv(const PALETTE_MODE_INFO *const pmi,
 // Extends 'color_map' array from 'orig_width x orig_height' to 'new_width x
 // new_height'. Extra rows and columns are filled in by copying last valid
 // row/column.
-static AOM_INLINE void extend_palette_color_map(uint8_t *const color_map,
-                                                int orig_width, int orig_height,
-                                                int new_width, int new_height) {
+static inline void extend_palette_color_map(uint8_t *const color_map,
+                                            int orig_width, int orig_height,
+                                            int new_width, int new_height) {
   int j;
   assert(new_width >= orig_width);
   assert(new_height >= orig_height);
@@ -187,10 +200,9 @@ static AOM_INLINE void extend_palette_color_map(uint8_t *const color_map,
 
 // Bias toward using colors in the cache.
 // TODO(huisu): Try other schemes to improve compression.
-static AOM_INLINE void optimize_palette_colors(uint16_t *color_cache,
-                                               int n_cache, int n_colors,
-                                               int stride, int16_t *centroids,
-                                               int bit_depth) {
+static inline void optimize_palette_colors(uint16_t *color_cache, int n_cache,
+                                           int n_colors, int stride,
+                                           int16_t *centroids, int bit_depth) {
   if (n_cache <= 0) return;
   for (int i = 0; i < n_colors * stride; i += stride) {
     int min_diff = abs((int)centroids[i] - (int)color_cache[0]);
@@ -214,7 +226,7 @@ static AOM_INLINE void optimize_palette_colors(uint16_t *color_cache,
  * Given the base colors as specified in centroids[], calculate the RD cost
  * of palette mode.
  */
-static AOM_INLINE void palette_rd_y(
+static inline void palette_rd_y(
     const AV1_COMP *const cpi, MACROBLOCK *x, MB_MODE_INFO *mbmi,
     BLOCK_SIZE bsize, int dc_mode_cost, const int16_t *data, int16_t *centroids,
     int n, uint16_t *color_cache, int n_cache, bool do_header_rd_based_gating,
@@ -226,7 +238,7 @@ static AOM_INLINE void palette_rd_y(
   if (do_header_rd_based_breakout != NULL) *do_header_rd_based_breakout = false;
   optimize_palette_colors(color_cache, n_cache, n, 1, centroids,
                           cpi->common.seq_params->bit_depth);
-  const int num_unique_colors = av1_remove_duplicates(centroids, n);
+  const int num_unique_colors = remove_duplicates(centroids, n);
   if (num_unique_colors < PALETTE_MIN_SIZE) {
     // Too few unique colors to create a palette. And DC_PRED will work
     // well for that case anyway. So skip.
@@ -313,7 +325,7 @@ static AOM_INLINE void palette_rd_y(
   }
 }
 
-static AOM_INLINE int is_iter_over(int curr_idx, int end_idx, int step_size) {
+static inline int is_iter_over(int curr_idx, int end_idx, int step_size) {
   assert(step_size != 0);
   return (step_size > 0) ? curr_idx >= end_idx : curr_idx <= end_idx;
 }
@@ -322,7 +334,7 @@ static AOM_INLINE int is_iter_over(int curr_idx, int end_idx, int step_size) {
 // [start_n, end_n) with step size step_size. If step_size < 0, then end_n can
 // be less than start_n. Saves the last numbers searched in last_n_searched and
 // returns the best number of colors found.
-static AOM_INLINE int perform_top_color_palette_search(
+static inline int perform_top_color_palette_search(
     const AV1_COMP *const cpi, MACROBLOCK *x, MB_MODE_INFO *mbmi,
     BLOCK_SIZE bsize, int dc_mode_cost, const int16_t *data,
     int16_t *top_colors, int start_n, int end_n, int step_size,
@@ -369,7 +381,7 @@ static AOM_INLINE int perform_top_color_palette_search(
 // [start_n, end_n) with step size step_size. If step_size < 0, then end_n can
 // be less than start_n. Saves the last numbers searched in last_n_searched and
 // returns the best number of colors found.
-static AOM_INLINE int perform_k_means_palette_search(
+static inline int perform_k_means_palette_search(
     const AV1_COMP *const cpi, MACROBLOCK *x, MB_MODE_INFO *mbmi,
     BLOCK_SIZE bsize, int dc_mode_cost, const int16_t *data, int lower_bound,
     int upper_bound, int start_n, int end_n, int step_size,
@@ -419,8 +431,8 @@ static AOM_INLINE int perform_k_means_palette_search(
 }
 
 // Sets the parameters to search the current number of colors +- 1
-static AOM_INLINE void set_stage2_params(int *min_n, int *max_n, int *step_size,
-                                         int winner, int end_n) {
+static inline void set_stage2_params(int *min_n, int *max_n, int *step_size,
+                                     int winner, int end_n) {
   // Set min to winner - 1 unless we are already at the border, then we set it
   // to winner + 1
   *min_n = (winner == PALETTE_MIN_SIZE) ? (PALETTE_MIN_SIZE + 1)
@@ -435,12 +447,12 @@ static AOM_INLINE void set_stage2_params(int *min_n, int *max_n, int *step_size,
   *step_size = AOMMAX(1, *max_n - *min_n);
 }
 
-static AOM_INLINE void fill_data_and_get_bounds(const uint8_t *src,
-                                                const int src_stride,
-                                                const int rows, const int cols,
-                                                const int is_high_bitdepth,
-                                                int16_t *data, int *lower_bound,
-                                                int *upper_bound) {
+static inline void fill_data_and_get_bounds(const uint8_t *src,
+                                            const int src_stride,
+                                            const int rows, const int cols,
+                                            const int is_high_bitdepth,
+                                            int16_t *data, int *lower_bound,
+                                            int *upper_bound) {
   if (is_high_bitdepth) {
     const uint16_t *src_ptr = CONVERT_TO_SHORTPTR(src);
     *lower_bound = *upper_bound = src_ptr[0];
@@ -480,7 +492,7 @@ struct ColorCount {
   int count;
 };
 
-int color_count_comp(const void *c1, const void *c2) {
+static int color_count_comp(const void *c1, const void *c2) {
   const struct ColorCount *color_count1 = (const struct ColorCount *)c1;
   const struct ColorCount *color_count2 = (const struct ColorCount *)c2;
   if (color_count1->count > color_count2->count) return -1;
@@ -549,7 +561,7 @@ void av1_rd_pick_palette_intra_sby(
   const SequenceHeader *const seq_params = cpi->common.seq_params;
   const int is_hbd = seq_params->use_highbitdepth;
   const int bit_depth = seq_params->bit_depth;
-  const int discount_color_cost = cpi->sf.rt_sf.use_nonrd_pick_mode;
+  const int discount_color_cost = cpi->sf.rt_sf.discount_color_cost;
   int unused;
 
   int count_buf[1 << 12];  // Maximum (1 << 12) color levels.
@@ -564,7 +576,7 @@ void av1_rd_pick_palette_intra_sby(
   }
 
   uint8_t *const color_map = xd->plane[0].color_index_map;
-  int color_thresh_palette = 64;
+  int color_thresh_palette = x->color_palette_thresh;
   // Allow for larger color_threshold for palette search, based on color,
   // scene_change, and block source variance.
   // Since palette is Y based, only allow larger threshold if block
