@@ -102,7 +102,7 @@ static int64_t try_filter_frame(const YV12_BUFFER_CONFIG *sd,
 static int search_filter_level(const YV12_BUFFER_CONFIG *sd, AV1_COMP *cpi,
                                int partial_frame,
                                const int *last_frame_filter_level, int plane,
-                               int dir) {
+                               int dir, int64_t *best_filter_sse) {
   const AV1_COMMON *const cm = &cpi->common;
   const int min_filter_level = 0;
   const int max_filter_level = get_max_filter_level(cpi);
@@ -203,6 +203,8 @@ static int search_filter_level(const YV12_BUFFER_CONFIG *sd, AV1_COMP *cpi,
     }
   }
 
+  *best_filter_sse = ss_err[filt_best];
+
   return filt_best;
 }
 
@@ -220,6 +222,23 @@ void av1_pick_filter_level(const YV12_BUFFER_CONFIG *sd, AV1_COMP *cpi,
   lf->sharpness_level =
       cpi->oxcf.mode == ALLINTRA ? cpi->oxcf.algo_cfg.sharpness : 0;
 
+  if (cpi->oxcf.algo_cfg.enable_adaptive_sharpness) {
+    // Loop filter sharpness levels are highly nonlinear. Visually, lf sharpness
+    // 1 is closer to 7 than it is to 0, so in practice adaptive sharpness is
+    // written to pick levels 0, 1 and 7 to keep it simple.
+    int max_lf_sharpness;
+
+    if (cm->quant_params.base_qindex <= 120) {
+      max_lf_sharpness = 7;
+    } else if (cm->quant_params.base_qindex <= 160) {
+      max_lf_sharpness = 1;
+    } else {
+      max_lf_sharpness = 0;
+    }
+
+    lf->sharpness_level = AOMMIN(lf->sharpness_level, max_lf_sharpness);
+  }
+
   if (cpi->oxcf.tune_cfg.content == AOM_CONTENT_SCREEN &&
       cpi->oxcf.q_cfg.aq_mode == CYCLIC_REFRESH_AQ &&
       cpi->sf.rt_sf.skip_lf_screen)
@@ -334,25 +353,106 @@ void av1_pick_filter_level(const YV12_BUFFER_CONFIG *sd, AV1_COMP *cpi,
       aom_internal_error(cm->error, AOM_CODEC_MEM_ERROR,
                          "Failed to allocate last frame buffer");
 
+    int64_t zero_filter_sse[MAX_MB_PLANE] = { 0 };
+    int64_t best_filter_sse[MAX_MB_PLANE] = { 0 };
+
+    if (cpi->sf.lpf_sf.skip_loop_filter_using_filt_error >= 1) {
+      for (int plane = 0; plane < num_planes; plane++) {
+        zero_filter_sse[plane] = aom_get_sse_plane(
+            sd, &cm->cur_frame->buf, plane, cm->seq_params->use_highbitdepth);
+      }
+    }
+
     lf->filter_level[0] = lf->filter_level[1] =
         search_filter_level(sd, cpi, method == LPF_PICK_FROM_SUBIMAGE,
-                            last_frame_filter_level, 0, 2);
+                            last_frame_filter_level, 0, 2, &best_filter_sse[0]);
     if (method != LPF_PICK_FROM_FULL_IMAGE_NON_DUAL) {
-      lf->filter_level[0] =
-          search_filter_level(sd, cpi, method == LPF_PICK_FROM_SUBIMAGE,
-                              last_frame_filter_level, 0, 0);
-      lf->filter_level[1] =
-          search_filter_level(sd, cpi, method == LPF_PICK_FROM_SUBIMAGE,
-                              last_frame_filter_level, 0, 1);
+      lf->filter_level[0] = search_filter_level(
+          sd, cpi, method == LPF_PICK_FROM_SUBIMAGE, last_frame_filter_level, 0,
+          0, &best_filter_sse[0]);
+      lf->filter_level[1] = search_filter_level(
+          sd, cpi, method == LPF_PICK_FROM_SUBIMAGE, last_frame_filter_level, 0,
+          1, &best_filter_sse[0]);
     }
 
     if (num_planes > 1) {
-      lf->filter_level_u =
-          search_filter_level(sd, cpi, method == LPF_PICK_FROM_SUBIMAGE,
-                              last_frame_filter_level, 1, 0);
-      lf->filter_level_v =
-          search_filter_level(sd, cpi, method == LPF_PICK_FROM_SUBIMAGE,
-                              last_frame_filter_level, 2, 0);
+      lf->filter_level_u = search_filter_level(
+          sd, cpi, method == LPF_PICK_FROM_SUBIMAGE, last_frame_filter_level, 1,
+          0, &best_filter_sse[1]);
+      lf->filter_level_v = search_filter_level(
+          sd, cpi, method == LPF_PICK_FROM_SUBIMAGE, last_frame_filter_level, 2,
+          0, &best_filter_sse[2]);
     }
+
+    lf->backup_filter_level[0] = lf->filter_level[0];
+    lf->backup_filter_level[1] = lf->filter_level[1];
+    lf->backup_filter_level_u = lf->filter_level_u;
+    lf->backup_filter_level_v = lf->filter_level_v;
+
+    if (cpi->sf.lpf_sf.adaptive_luma_loop_filter_skip >= 1) {
+      int32_t min_ref_filter_level[2] = { MAX_LOOP_FILTER, MAX_LOOP_FILTER };
+      // Find the minimum luma filter levels across all reference frames.
+      for (int ref = LAST_FRAME; ref <= ALTREF_FRAME; ++ref) {
+        const RefCntBuffer *const buf = get_ref_frame_buf(cm, ref);
+        if (buf == NULL) continue;
+
+        if (buf->filter_level[0] != -1)
+          min_ref_filter_level[0] =
+              AOMMIN(min_ref_filter_level[0], buf->filter_level[0]);
+        if (buf->filter_level[1] != -1)
+          min_ref_filter_level[1] =
+              AOMMIN(min_ref_filter_level[1], buf->filter_level[1]);
+      }
+
+      // Reset luma filter levels to zero based on minimum filter levels of
+      // reference frames and current frame's pyramid level.
+      unsigned int pyramid_level = cm->current_frame.pyramid_level;
+      if (pyramid_level > 1) {
+        int filter_threshold;
+        if (pyramid_level >= 5)
+          filter_threshold = 32;
+        else if (pyramid_level >= 4)
+          filter_threshold = 16;
+        else
+          filter_threshold = 8;
+
+        const bool reset_filter_level_y =
+            lf->filter_level[0] < filter_threshold &&
+            lf->filter_level[1] < filter_threshold &&
+            lf->filter_level_u < filter_threshold &&
+            lf->filter_level_v < filter_threshold &&
+            min_ref_filter_level[0] == 0 && min_ref_filter_level[1] == 0;
+        if (reset_filter_level_y) {
+          lf->filter_level[0] = 0;
+          lf->filter_level[1] = 0;
+        }
+      }
+    }
+
+    if (lf->filter_level[0] != 0 && lf->filter_level[1] != 0 &&
+        cpi->sf.lpf_sf.skip_loop_filter_using_filt_error >= 1) {
+      const double pct_improvement_thresh = 2.0;
+      bool reset_filter_level_y = true;
+
+      // Calculate the percentage improvement in SSE for each plane. This
+      // measures the relative reduction in error when applying the filter
+      // compared to no filtering.
+      for (int plane = 0; plane < num_planes; plane++) {
+        const double pct_improvement_sse =
+            ((zero_filter_sse[plane] - best_filter_sse[plane]) * 100.0) /
+            zero_filter_sse[plane];
+        reset_filter_level_y &= pct_improvement_sse < pct_improvement_thresh;
+      }
+
+      if (reset_filter_level_y) {
+        lf->filter_level[0] = 0;
+        lf->filter_level[1] = 0;
+      }
+    }
+
+    // Store the current frame's filter levels to be referenced
+    // while determining the minimum filter level from reference frames.
+    cm->cur_frame->filter_level[0] = lf->filter_level[0];
+    cm->cur_frame->filter_level[1] = lf->filter_level[1];
   }
 }
