@@ -25,6 +25,7 @@
 
 #include "av1/common/reconinter.h"
 #include "av1/common/blockd.h"
+#include "av1/common/quant_common.h"
 
 #include "av1/encoder/encodeframe.h"
 #include "av1/encoder/encodeframe_utils.h"
@@ -549,7 +550,7 @@ static void set_vbp_thresholds_key_frame(AV1_COMP *cpi, int64_t thresholds[],
   } else {
     int shift_val = 2;
     if (cpi->sf.rt_sf.force_large_partition_blocks_intra) {
-      shift_val = 0;
+      shift_val = (cpi->oxcf.mode == ALLINTRA ? 1 : 0);
     }
 
     thresholds[2] = threshold_base >> shift_val;
@@ -646,7 +647,7 @@ static inline int64_t tune_base_thresh_content(AV1_COMP *cpi,
       cpi->ppi->rtc_ref.non_reference_frame, cpi->rc.frame_source_sad == 0);
   if (cpi->oxcf.speed >= 11 && source_sad_nonrd > kLowSad &&
       cpi->rc.high_motion_content_screen_rtc)
-    updated_thresh_base = updated_thresh_base << 5;
+    updated_thresh_base = updated_thresh_base << 4;
   return updated_thresh_base;
 }
 
@@ -1218,10 +1219,13 @@ static inline void set_ref_frame_for_partition(
     const YV12_BUFFER_CONFIG *yv12_g, const YV12_BUFFER_CONFIG *yv12_alt,
     int mi_row, int mi_col, int num_planes) {
   AV1_COMMON *const cm = &cpi->common;
+  const double fac =
+      (cpi->svc.spatial_layer_id > 0 && cpi->svc.has_lower_quality_layer) ? 1.0
+                                                                          : 0.9;
   const bool is_set_golden_ref_frame =
-      *y_sad_g < 0.9 * *y_sad && *y_sad_g < *y_sad_alt;
+      *y_sad_g < fac * *y_sad && *y_sad_g < *y_sad_alt;
   const bool is_set_altref_ref_frame =
-      *y_sad_alt < 0.9 * *y_sad && *y_sad_alt < *y_sad_g;
+      *y_sad_alt < fac * *y_sad && *y_sad_alt < *y_sad_g;
 
   if (is_set_golden_ref_frame) {
     av1_setup_pre_planes(xd, 0, yv12_g, mi_row, mi_col,
@@ -1325,6 +1329,58 @@ static inline void evaluate_neighbour_mvs(AV1_COMP *cpi, MACROBLOCK *x,
   }
 }
 
+static void do_int_pro_motion_estimation(AV1_COMP *cpi, MACROBLOCK *x,
+                                         unsigned int *y_sad, int mi_row,
+                                         int mi_col, int source_sad_nonrd) {
+  AV1_COMMON *const cm = &cpi->common;
+  MACROBLOCKD *xd = &x->e_mbd;
+  MB_MODE_INFO *mi = xd->mi[0];
+  const int is_screen = cpi->oxcf.tune_cfg.content == AOM_CONTENT_SCREEN;
+  const int increase_col_sw = source_sad_nonrd > kMedSad &&
+                              !cpi->rc.high_motion_content_screen_rtc &&
+                              (cpi->svc.temporal_layer_id == 0 ||
+                               cpi->rc.num_col_blscroll_last_tl0 > 2);
+  int me_search_size_col = is_screen
+                               ? increase_col_sw ? 512 : 96
+                               : block_size_wide[cm->seq_params->sb_size] >> 1;
+  // For screen use larger search size row motion to capture
+  // vertical scroll, which can be larger motion.
+  int me_search_size_row = is_screen
+                               ? source_sad_nonrd > kMedSad ? 512 : 192
+                               : block_size_high[cm->seq_params->sb_size] >> 1;
+  if (cm->width * cm->height >= 3840 * 2160 &&
+      cpi->svc.temporal_layer_id == 0 && cpi->svc.number_temporal_layers > 1) {
+    me_search_size_row = me_search_size_row << 1;
+    me_search_size_col = me_search_size_col << 1;
+  }
+  unsigned int y_sad_zero;
+  *y_sad = av1_int_pro_motion_estimation(
+      cpi, x, cm->seq_params->sb_size, mi_row, mi_col, &kZeroMv, &y_sad_zero,
+      me_search_size_col, me_search_size_row);
+  // The logic below selects whether the motion estimated in the
+  // int_pro_motion() will be used in nonrd_pickmode. Only do this
+  // for screen for now.
+  if (is_screen) {
+    unsigned int thresh_sad =
+        (cm->seq_params->sb_size == BLOCK_128X128) ? 50000 : 20000;
+    if (*y_sad < (y_sad_zero >> 1) && *y_sad < thresh_sad) {
+      x->sb_me_partition = 1;
+      x->sb_me_mv.as_int = mi->mv[0].as_int;
+      if (cpi->svc.temporal_layer_id == 0) {
+        if (abs(mi->mv[0].as_mv.col) > 16 && abs(mi->mv[0].as_mv.row) == 0)
+          x->sb_col_scroll = 1;
+        else if (abs(mi->mv[0].as_mv.row) > 16 && abs(mi->mv[0].as_mv.col) == 0)
+          x->sb_row_scroll = 1;
+      }
+    } else {
+      x->sb_me_partition = 0;
+      // Fall back to using zero motion.
+      *y_sad = y_sad_zero;
+      mi->mv[0].as_int = 0;
+    }
+  }
+}
+
 static void setup_planes(AV1_COMP *cpi, MACROBLOCK *x, unsigned int *y_sad,
                          unsigned int *y_sad_g, unsigned int *y_sad_alt,
                          unsigned int *y_sad_last,
@@ -1354,9 +1410,11 @@ static void setup_planes(AV1_COMP *cpi, MACROBLOCK *x, unsigned int *y_sad,
                     (cpi->sf.rt_sf.use_comp_ref_nonrd &&
                      cpi->sf.rt_sf.ref_frame_comp_nonrd[2] == 1);
 
-  // For 1 spatial layer: GOLDEN is another temporal reference.
-  // Check if it should be used as reference for partitioning.
-  if (cpi->svc.number_spatial_layers == 1 && use_golden_ref &&
+  // Check if GOLDEN should be used as reference for partitioning.
+  // Allow for spatial layers if lower layer has same resolution.
+  if ((cpi->svc.number_spatial_layers == 1 ||
+       cpi->svc.has_lower_quality_layer) &&
+      use_golden_ref &&
       (x->content_state_sb.source_sad_nonrd != kZeroSad || !use_last_ref)) {
     yv12_g = get_ref_frame_yv12_buf(cm, GOLDEN_FRAME);
     if (yv12_g && (yv12_g->y_crop_height != cm->height ||
@@ -1364,7 +1422,7 @@ static void setup_planes(AV1_COMP *cpi, MACROBLOCK *x, unsigned int *y_sad,
       yv12_g = av1_get_scaled_ref_frame(cpi, GOLDEN_FRAME);
       scaled_ref_golden = true;
     }
-    if (yv12_g && yv12_g != yv12) {
+    if (yv12_g && (yv12_g != yv12 || !use_last_ref)) {
       av1_setup_pre_planes(
           xd, 0, yv12_g, mi_row, mi_col,
           scaled_ref_golden ? NULL : get_ref_scale_factors(cm, GOLDEN_FRAME),
@@ -1376,10 +1434,11 @@ static void setup_planes(AV1_COMP *cpi, MACROBLOCK *x, unsigned int *y_sad,
     }
   }
 
-  // For 1 spatial layer: ALTREF is another temporal reference.
-  // Check if it should be used as reference for partitioning.
-  if (cpi->svc.number_spatial_layers == 1 && use_alt_ref &&
-      (cpi->ref_frame_flags & AOM_ALT_FLAG) &&
+  // Check if ALTREF should be used as reference for partitioning.
+  // Allow for spatial layers if lower layer has same resolution.
+  if ((cpi->svc.number_spatial_layers == 1 ||
+       cpi->svc.has_lower_quality_layer) &&
+      use_alt_ref && (cpi->ref_frame_flags & AOM_ALT_FLAG) &&
       (x->content_state_sb.source_sad_nonrd != kZeroSad || !use_last_ref)) {
     yv12_alt = get_ref_frame_yv12_buf(cm, ALTREF_FRAME);
     if (yv12_alt && (yv12_alt->y_crop_height != cm->height ||
@@ -1387,7 +1446,7 @@ static void setup_planes(AV1_COMP *cpi, MACROBLOCK *x, unsigned int *y_sad,
       yv12_alt = av1_get_scaled_ref_frame(cpi, ALTREF_FRAME);
       scaled_ref_alt = true;
     }
-    if (yv12_alt && yv12_alt != yv12) {
+    if (yv12_alt && (yv12_alt != yv12 || !use_last_ref)) {
       av1_setup_pre_planes(
           xd, 0, yv12_alt, mi_row, mi_col,
           scaled_ref_alt ? NULL : get_ref_scale_factors(cm, ALTREF_FRAME),
@@ -1418,40 +1477,11 @@ static void setup_planes(AV1_COMP *cpi, MACROBLOCK *x, unsigned int *y_sad,
     // so for now force it to 2 based on superblock sad.
     if (est_motion > 2 && source_sad_nonrd > kMedSad) est_motion = 2;
 
-    if (est_motion == 1 || est_motion == 2) {
-      if (xd->mb_to_right_edge >= 0 && xd->mb_to_bottom_edge >= 0) {
-        // For screen only do int_pro_motion for spatial variance above
-        // threshold and motion level above LowSad.
-        if (x->source_variance > 100 && source_sad_nonrd > kLowSad) {
-          int is_screen = cpi->oxcf.tune_cfg.content == AOM_CONTENT_SCREEN;
-          int me_search_size_col =
-              is_screen ? 96 : block_size_wide[cm->seq_params->sb_size] >> 1;
-          // For screen use larger search size row motion to capture
-          // vertical scroll, which can be larger motion.
-          int me_search_size_row =
-              is_screen ? 192 : block_size_high[cm->seq_params->sb_size] >> 1;
-          unsigned int y_sad_zero;
-          *y_sad = av1_int_pro_motion_estimation(
-              cpi, x, cm->seq_params->sb_size, mi_row, mi_col, &kZeroMv,
-              &y_sad_zero, me_search_size_col, me_search_size_row);
-          // The logic below selects whether the motion estimated in the
-          // int_pro_motion() will be used in nonrd_pickmode. Only do this
-          // for screen for now.
-          if (is_screen) {
-            unsigned int thresh_sad =
-                (cm->seq_params->sb_size == BLOCK_128X128) ? 50000 : 20000;
-            if (*y_sad < (y_sad_zero >> 1) && *y_sad < thresh_sad) {
-              x->sb_me_partition = 1;
-              x->sb_me_mv.as_int = mi->mv[0].as_int;
-            } else {
-              x->sb_me_partition = 0;
-              // Fall back to using zero motion.
-              *y_sad = y_sad_zero;
-              mi->mv[0].as_int = 0;
-            }
-          }
-        }
-      }
+    if ((est_motion == 1 || est_motion == 2) && xd->mb_to_right_edge >= 0 &&
+        xd->mb_to_bottom_edge >= 0 && x->source_variance > 100 &&
+        source_sad_nonrd > kLowSad) {
+      do_int_pro_motion_estimation(cpi, x, y_sad, mi_row, mi_col,
+                                   source_sad_nonrd);
     }
 
     if (*y_sad == UINT_MAX) {
@@ -1645,10 +1675,14 @@ int av1_choose_var_based_partitioning(AV1_COMP *cpi, const TileInfo *const tile,
   const bool is_segment_id_boosted =
       cpi->oxcf.q_cfg.aq_mode == CYCLIC_REFRESH_AQ && cm->seg.enabled &&
       cyclic_refresh_segment_id_boosted(segment_id);
-  const int qindex =
-      is_segment_id_boosted
-          ? av1_get_qindex(&cm->seg, segment_id, cm->quant_params.base_qindex)
-          : cm->quant_params.base_qindex;
+  const int sb_qindex =
+      clamp(cm->delta_q_info.delta_q_present_flag
+                ? cm->quant_params.base_qindex + x->delta_qindex
+                : cm->quant_params.base_qindex,
+            0, QINDEX_RANGE - 1);
+  const int qindex = is_segment_id_boosted || cpi->roi.delta_qp_enabled
+                         ? av1_get_qindex(&cm->seg, segment_id, sb_qindex)
+                         : sb_qindex;
   set_vbp_thresholds(
       cpi, thresholds, blk_sad, qindex, x->content_state_sb.low_sumdiff,
       x->content_state_sb.source_sad_nonrd, x->content_state_sb.source_sad_rd,
