@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -153,10 +153,8 @@ static const arg_def_t *main_args[] = { &limit_arg,
                                         &skip_non_transform_arg,
                                         &combined_arg,
                                         NULL };
-#define ENUM(name) \
-  { #name, name }
-#define LAST_ENUM \
-  { NULL, 0 }
+#define ENUM(name) { #name, name }
+#define LAST_ENUM { NULL, 0 }
 typedef struct map_entry {
   const char *name;
   int value;
@@ -280,7 +278,8 @@ struct parm_offset parm_offsets[] = {
 };
 int parm_count = sizeof(parm_offsets) / sizeof(parm_offsets[0]);
 
-int convert_to_indices(char *str, int *indices, int maxCount, int *count) {
+static int convert_to_indices(char *str, int *indices, int maxCount,
+                              int *count) {
   *count = 0;
   do {
     char *comma = strchr(str, ',');
@@ -307,7 +306,7 @@ AvxVideoReader *reader = NULL;
 const AvxVideoInfo *info = NULL;
 aom_image_t *img = NULL;
 
-void on_frame_decoded_dump(char *json) {
+static void on_frame_decoded_dump(char *json) {
 #ifdef __EMSCRIPTEN__
   EM_ASM_({ Module.on_frame_decoded_json($0); }, json);
 #else
@@ -317,7 +316,7 @@ void on_frame_decoded_dump(char *json) {
 
 // Writing out the JSON buffer using snprintf is very slow, especially when
 // compiled with emscripten, these functions speed things up quite a bit.
-int put_str(char *buffer, const char *str) {
+static int put_str(char *buffer, const char *str) {
   int i;
   for (i = 0; str[i] != '\0'; i++) {
     buffer[i] = str[i];
@@ -325,7 +324,7 @@ int put_str(char *buffer, const char *str) {
   return i;
 }
 
-int put_str_with_escape(char *buffer, const char *str) {
+static int put_str_with_escape(char *buffer, const char *str) {
   int i;
   int j = 0;
   for (i = 0; str[i] != '\0'; i++) {
@@ -339,7 +338,7 @@ int put_str_with_escape(char *buffer, const char *str) {
   return j;
 }
 
-int put_num(char *buffer, char prefix, int num, char suffix) {
+static int put_num(char *buffer, char prefix, int num, char suffix) {
   int i = 0;
   char *buf = buffer;
   int is_neg = 0;
@@ -376,7 +375,7 @@ int put_num(char *buffer, char prefix, int num, char suffix) {
   return i;
 }
 
-int put_map(char *buffer, const map_entry *map) {
+static int put_map(char *buffer, const map_entry *map) {
   char *buf = buffer;
   const map_entry *entry = map;
   while (entry->name != NULL) {
@@ -392,7 +391,8 @@ int put_map(char *buffer, const map_entry *map) {
   return (int)(buf - buffer);
 }
 
-int put_reference_frame(char *buffer) {
+#if 0
+static int put_reference_frame(char *buffer) {
   const int mi_rows = frame_data.mi_rows;
   const int mi_cols = frame_data.mi_cols;
   char *buf = buffer;
@@ -429,8 +429,9 @@ int put_reference_frame(char *buffer) {
   buf += put_str(buf, "],\n");
   return (int)(buf - buffer);
 }
+#endif
 
-int put_motion_vectors(char *buffer) {
+static int put_motion_vectors(char *buffer) {
   const int mi_rows = frame_data.mi_rows;
   const int mi_cols = frame_data.mi_cols;
   char *buf = buffer;
@@ -469,7 +470,7 @@ int put_motion_vectors(char *buffer) {
   return (int)(buf - buffer);
 }
 
-int put_combined(char *buffer) {
+static int put_combined(char *buffer) {
   const int mi_rows = frame_data.mi_rows;
   const int mi_cols = frame_data.mi_cols;
   char *buf = buffer;
@@ -501,8 +502,8 @@ int put_combined(char *buffer) {
   return (int)(buf - buffer);
 }
 
-int put_block_info(char *buffer, const map_entry *map, const char *name,
-                   size_t offset, int len) {
+static int put_block_info(char *buffer, const map_entry *map, const char *name,
+                          size_t offset, int len) {
   const int mi_rows = frame_data.mi_rows;
   const int mi_cols = frame_data.mi_cols;
   char *buf = buffer;
@@ -568,7 +569,7 @@ int put_block_info(char *buffer, const map_entry *map, const char *name,
 }
 
 #if CONFIG_ACCOUNTING
-int put_accounting(char *buffer) {
+static int put_accounting(char *buffer) {
   char *buf = buffer;
   int i;
   const Accounting *accounting = frame_data.accounting;
@@ -610,7 +611,7 @@ int put_accounting(char *buffer) {
 
 int skip_non_transform = 0;
 
-void inspect(void *pbi, void *data) {
+static void inspect(void *pbi, void *data) {
   /* Fetch frame data. */
   ifd_inspect(&frame_data, pbi, skip_non_transform);
 
@@ -621,7 +622,7 @@ void inspect(void *pbi, void *data) {
   (void)data;
   // We allocate enough space and hope we don't write out of bounds. Totally
   // unsafe but this speeds things up, especially when compiled to Javascript.
-  char *buffer = aom_malloc(MAX_BUFFER);
+  char *buffer = malloc(MAX_BUFFER);
   if (!buffer) {
     fprintf(stderr, "Error allocating inspect info buffer\n");
     abort();
@@ -739,16 +740,18 @@ void inspect(void *pbi, void *data) {
   buf += put_str(buf, "},\n");
   *(buf++) = 0;
   on_frame_decoded_dump(buffer);
-  aom_free(buffer);
+  free(buffer);
 }
 
-void ifd_init_cb() {
+static void ifd_init_cb(void) {
   aom_inspect_init ii;
   ii.inspect_cb = inspect;
   ii.inspect_ctx = NULL;
   aom_codec_control(&codec, AV1_SET_INSPECTION_CALLBACK, &ii);
 }
 
+EMSCRIPTEN_KEEPALIVE int open_file(char *file);
+
 EMSCRIPTEN_KEEPALIVE
 int open_file(char *file) {
   if (file == NULL) {
@@ -773,9 +776,12 @@ int have_frame = 0;
 const unsigned char *frame;
 const unsigned char *end_frame;
 size_t frame_size = 0;
+struct av1_ref_frame ref_dec;
+
+EMSCRIPTEN_KEEPALIVE int read_frame(void);
 
 EMSCRIPTEN_KEEPALIVE
-int read_frame() {
+int read_frame(void) {
   img = NULL;
 
   // This loop skips over any frames that are show_existing_frames,  as
@@ -801,7 +807,6 @@ int read_frame() {
 
   int got_any_frames = 0;
   aom_image_t *frame_img;
-  struct av1_ref_frame ref_dec;
   ref_dec.idx = adr.idx;
 
   // ref_dec.idx is the index to the reference buffer idx to AV1_GET_REFERENCE
@@ -823,35 +828,57 @@ int read_frame() {
   return EXIT_SUCCESS;
 }
 
-EMSCRIPTEN_KEEPALIVE
-const char *get_aom_codec_build_config() { return aom_codec_build_config(); }
+EMSCRIPTEN_KEEPALIVE const char *get_aom_codec_build_config(void);
 
 EMSCRIPTEN_KEEPALIVE
-int get_bit_depth() { return img->bit_depth; }
+const char *get_aom_codec_build_config(void) {
+  return aom_codec_build_config();
+}
+
+EMSCRIPTEN_KEEPALIVE int get_bit_depth(void);
 
 EMSCRIPTEN_KEEPALIVE
-int get_bits_per_sample() { return img->bps; }
+int get_bit_depth(void) { return img->bit_depth; }
+
+EMSCRIPTEN_KEEPALIVE int get_bits_per_sample(void);
 
 EMSCRIPTEN_KEEPALIVE
-int get_image_format() { return img->fmt; }
+int get_bits_per_sample(void) { return img->bps; }
+
+EMSCRIPTEN_KEEPALIVE int get_image_format(void);
+
+EMSCRIPTEN_KEEPALIVE
+int get_image_format(void) { return img->fmt; }
+
+EMSCRIPTEN_KEEPALIVE unsigned char *get_plane(int plane);
 
 EMSCRIPTEN_KEEPALIVE
 unsigned char *get_plane(int plane) { return img->planes[plane]; }
 
+EMSCRIPTEN_KEEPALIVE int get_plane_stride(int plane);
+
 EMSCRIPTEN_KEEPALIVE
 int get_plane_stride(int plane) { return img->stride[plane]; }
 
+EMSCRIPTEN_KEEPALIVE int get_plane_width(int plane);
+
 EMSCRIPTEN_KEEPALIVE
 int get_plane_width(int plane) { return aom_img_plane_width(img, plane); }
 
+EMSCRIPTEN_KEEPALIVE int get_plane_height(int plane);
+
 EMSCRIPTEN_KEEPALIVE
 int get_plane_height(int plane) { return aom_img_plane_height(img, plane); }
 
-EMSCRIPTEN_KEEPALIVE
-int get_frame_width() { return info->frame_width; }
+EMSCRIPTEN_KEEPALIVE int get_frame_width(void);
 
 EMSCRIPTEN_KEEPALIVE
-int get_frame_height() { return info->frame_height; }
+int get_frame_width(void) { return info->frame_width; }
+
+EMSCRIPTEN_KEEPALIVE int get_frame_height(void);
+
+EMSCRIPTEN_KEEPALIVE
+int get_frame_height(void) { return info->frame_height; }
 
 static void parse_args(char **argv) {
   char **argi, **argj;
@@ -948,14 +975,20 @@ int main(int argc, char **argv) {
   }
 }
 
+EMSCRIPTEN_KEEPALIVE void quit(void);
+
 EMSCRIPTEN_KEEPALIVE
-void quit() {
+void quit(void) {
   if (aom_codec_destroy(&codec)) die_codec(&codec, "Failed to destroy codec");
   aom_video_reader_close(reader);
 }
 
+EMSCRIPTEN_KEEPALIVE void set_layers(LayerType v);
+
 EMSCRIPTEN_KEEPALIVE
 void set_layers(LayerType v) { layers = v; }
 
+EMSCRIPTEN_KEEPALIVE void set_compress(int v);
+
 EMSCRIPTEN_KEEPALIVE
 void set_compress(int v) { compress = v; }
