@@ -438,6 +438,11 @@ INSTANTIATE_TEST_SUITE_P(NEON_I8MM, AV1ConvolveXTest,
                          BuildLowbdParams(av1_convolve_x_sr_neon_i8mm));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1ConvolveXTest,
+                         BuildLowbdParams(av1_convolve_x_sr_rvv));
+#endif
+
 ////////////////////////////////////////////////////////////////
 // Single reference convolve-x IntraBC functions (low bit-depth)
 ////////////////////////////////////////////////////////////////
@@ -521,6 +526,11 @@ INSTANTIATE_TEST_SUITE_P(NEON, AV1ConvolveXIntraBCTest,
                          BuildLowbdParams(av1_convolve_x_sr_intrabc_neon));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1ConvolveXIntraBCTest,
+                         BuildLowbdParams(av1_convolve_x_sr_intrabc_rvv));
+#endif
+
 #if CONFIG_AV1_HIGHBITDEPTH
 /////////////////////////////////////////////////////////
 // Single reference convolve-x functions (high bit-depth)
@@ -640,6 +650,11 @@ INSTANTIATE_TEST_SUITE_P(SVE2, AV1ConvolveXHighbdTest,
                          BuildHighbdParams(av1_highbd_convolve_x_sr_sve2));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1ConvolveXHighbdTest,
+                         BuildHighbdParams(av1_highbd_convolve_x_sr_rvv));
+#endif
+
 /////////////////////////////////////////////////////////////////
 // Single reference convolve-x IntraBC functions (high bit-depth)
 /////////////////////////////////////////////////////////////////
@@ -728,6 +743,12 @@ INSTANTIATE_TEST_SUITE_P(
     BuildHighbdParams(av1_highbd_convolve_x_sr_intrabc_neon));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(
+    RVV, AV1ConvolveXHighbdIntraBCTest,
+    BuildHighbdParams(av1_highbd_convolve_x_sr_intrabc_rvv));
+#endif
+
 #endif  // CONFIG_AV1_HIGHBITDEPTH
 
 ////////////////////////////////////////////////////////
@@ -842,6 +863,11 @@ INSTANTIATE_TEST_SUITE_P(NEON_I8MM, AV1ConvolveYTest,
                          BuildLowbdParams(av1_convolve_y_sr_neon_i8mm));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1ConvolveYTest,
+                         BuildLowbdParams(av1_convolve_y_sr_rvv));
+#endif
+
 ////////////////////////////////////////////////////////////////
 // Single reference convolve-y IntraBC functions (low bit-depth)
 ////////////////////////////////////////////////////////////////
@@ -916,6 +942,11 @@ INSTANTIATE_TEST_SUITE_P(NEON, AV1ConvolveYIntraBCTest,
                          BuildLowbdParams(av1_convolve_y_sr_intrabc_neon));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1ConvolveYIntraBCTest,
+                         BuildLowbdParams(av1_convolve_y_sr_intrabc_rvv));
+#endif
+
 #if CONFIG_AV1_HIGHBITDEPTH
 /////////////////////////////////////////////////////////
 // Single reference convolve-y functions (high bit-depth)
@@ -1024,6 +1055,11 @@ INSTANTIATE_TEST_SUITE_P(SVE2, AV1ConvolveYHighbdTest,
                          BuildHighbdParams(av1_highbd_convolve_y_sr_sve2));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1ConvolveYHighbdTest,
+                         BuildHighbdParams(av1_highbd_convolve_y_sr_rvv));
+#endif
+
 /////////////////////////////////////////////////////////////////
 // Single reference convolve-y IntraBC functions (high bit-depth)
 /////////////////////////////////////////////////////////////////
@@ -1104,6 +1140,12 @@ INSTANTIATE_TEST_SUITE_P(
     BuildHighbdParams(av1_highbd_convolve_y_sr_intrabc_neon));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(
+    RVV, AV1ConvolveYHighbdIntraBCTest,
+    BuildHighbdParams(av1_highbd_convolve_y_sr_intrabc_rvv));
+#endif
+
 #endif  // CONFIG_AV1_HIGHBITDEPTH
 
 //////////////////////////////////////////////////////////////
@@ -1338,6 +1380,11 @@ INSTANTIATE_TEST_SUITE_P(SVE2, AV1Convolve2DTest,
                          BuildLowbdParams(av1_convolve_2d_sr_sve2));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1Convolve2DTest,
+                         BuildLowbdParams(av1_convolve_2d_sr_rvv));
+#endif
+
 /////////////////////////////////////////////////////////////////
 // Single reference convolve-2D IntraBC functions (low bit-depth)
 /////////////////////////////////////////////////////////////////
@@ -1426,6 +1473,11 @@ INSTANTIATE_TEST_SUITE_P(NEON, AV1Convolve2DIntraBCTest,
                          BuildLowbdParams(av1_convolve_2d_sr_intrabc_neon));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1Convolve2DIntraBCTest,
+                         BuildLowbdParams(av1_convolve_2d_sr_intrabc_rvv));
+#endif
+
 #if CONFIG_AV1_HIGHBITDEPTH
 //////////////////////////////////////////////////////////
 // Single reference convolve-2d functions (high bit-depth)
@@ -1561,6 +1613,11 @@ INSTANTIATE_TEST_SUITE_P(SVE2, AV1Convolve2DHighbdTest,
                          BuildHighbdParams(av1_highbd_convolve_2d_sr_sve2));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(RVV, AV1Convolve2DHighbdTest,
+                         BuildHighbdParams(av1_highbd_convolve_2d_sr_rvv));
+#endif
+
 //////////////////////////////////////////////////////////////////
 // Single reference convolve-2d IntraBC functions (high bit-depth)
 //////////////////////////////////////////////////////////////////
@@ -1658,6 +1715,12 @@ INSTANTIATE_TEST_SUITE_P(
     BuildHighbdParams(av1_highbd_convolve_2d_sr_intrabc_neon));
 #endif
 
+#if HAVE_RVV
+INSTANTIATE_TEST_SUITE_P(
+    RVV, AV1Convolve2DHighbdIntraBCTest,
+    BuildHighbdParams(av1_highbd_convolve_2d_sr_intrabc_rvv));
+#endif
+
 #endif  // CONFIG_AV1_HIGHBITDEPTH
 
 //////////////////////////
