@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2021, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -18,7 +18,7 @@
 #include "aom/aom_external_partition.h"
 #include "av1/common/blockd.h"
 #include "av1/encoder/encodeframe_utils.h"
-#include "third_party/googletest/src/googletest/include/gtest/gtest.h"
+#include "gtest/gtest.h"
 #include "test/codec_factory.h"
 #include "test/encode_test_driver.h"
 #include "test/y4m_video_source.h"
@@ -114,7 +114,7 @@ aom_ext_part_status_t ext_part_get_partition_decision_whole_tree(
     ext_part_decision->partition_decision[4] = PARTITION_NONE;
     // The rest blocks inside the top-left 32x32 block.
     for (int i = 5; i < num_blocks - num_4x4_blocks; ++i) {
-      ext_part_decision->partition_decision[0] = PARTITION_SPLIT;
+      ext_part_decision->partition_decision[i] = PARTITION_SPLIT;
     }
     for (int i = num_blocks - num_4x4_blocks; i < num_blocks; ++i) {
       ext_part_decision->partition_decision[i] = PARTITION_NONE;
@@ -138,7 +138,7 @@ aom_ext_part_status_t ext_part_get_partition_decision_whole_tree(
     ext_part_decision->partition_decision[4] = PARTITION_NONE;
     // The rest blocks.
     for (int i = 5; i < num_blocks - num_4x4_blocks; ++i) {
-      ext_part_decision->partition_decision[0] = PARTITION_SPLIT;
+      ext_part_decision->partition_decision[i] = PARTITION_SPLIT;
     }
     for (int i = num_blocks - num_4x4_blocks; i < num_blocks; ++i) {
       ext_part_decision->partition_decision[i] = PARTITION_NONE;
@@ -162,7 +162,7 @@ aom_ext_part_status_t ext_part_get_partition_decision_whole_tree(
     ext_part_decision->partition_decision[4] = PARTITION_NONE;
     // The rest blocks.
     for (int i = 5; i < num_blocks - num_4x4_blocks; ++i) {
-      ext_part_decision->partition_decision[0] = PARTITION_SPLIT;
+      ext_part_decision->partition_decision[i] = PARTITION_SPLIT;
     }
     for (int i = num_blocks - num_4x4_blocks; i < num_blocks; ++i) {
       ext_part_decision->partition_decision[i] = PARTITION_NONE;
