@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2018, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -20,8 +20,8 @@
 #include "aom_mem/aom_mem.h"
 #include "av1/common/common.h"
 #include "config/aom_dsp_rtcd.h"
+#include "gtest/gtest.h"
 #include "test/acm_random.h"
-#include "third_party/googletest/src/googletest/include/gtest/gtest.h"
 
 namespace {
 
