@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -10,12 +10,12 @@
  */
 #include "config/aom_config.h"
 
-#include "third_party/googletest/src/googletest/include/gtest/gtest.h"
+#include "av1/encoder/av1_quantize.h"
+#include "gtest/gtest.h"
 #include "test/codec_factory.h"
 #include "test/encode_test_driver.h"
 #include "test/i420_video_source.h"
 #include "test/util.h"
-#include "av1/encoder/av1_quantize.h"
 #include "test/y4m_video_source.h"
 
 namespace {
