@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2019, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -14,7 +14,7 @@
 #include <string>
 #include <unordered_map>
 
-#include "third_party/googletest/src/googletest/include/gtest/gtest.h"
+#include "gtest/gtest.h"
 
 #include "test/codec_factory.h"
 #include "test/encode_test_driver.h"
@@ -32,33 +32,33 @@ const int kBitrate = 500;
 std::unordered_map<std::string,
                    std::unordered_map<int, std::unordered_map<int, double>>>
     kPsnrThreshold = { { "park_joy_90p_8_420.y4m",
-                         { { 5, { { 0, 35.4 }, { 3, 36.3 } } },
-                           { 6, { { 0, 35.3 }, { 3, 36.2 } } },
-                           { 7, { { 0, 34.9 }, { 3, 35.8 } } },
-                           { 8, { { 0, 35.0 }, { 3, 35.8 } } },
-                           { 9, { { 0, 34.9 }, { 3, 35.5 } } },
-                           { 10, { { 0, 34.7 }, { 3, 35.3 } } } } },
+                         { { 5, { { 0, 34.0 }, { 3, 35.0 } } },
+                           { 6, { { 0, 34.0 }, { 3, 35.0 } } },
+                           { 7, { { 0, 33.0 }, { 3, 34.0 } } },
+                           { 8, { { 0, 33.0 }, { 3, 34.0 } } },
+                           { 9, { { 0, 33.0 }, { 3, 34.0 } } },
+                           { 10, { { 0, 33.0 }, { 3, 34.0 } } } } },
                        { "paris_352_288_30.y4m",
-                         { { 5, { { 0, 36.2 }, { 3, 36.7 } } },
-                           { 6, { { 0, 36.1 }, { 3, 36.48 } } },
-                           { 7, { { 0, 35.5 }, { 3, 36.0 } } },
-                           { 8, { { 0, 35.8 }, { 3, 36.4 } } },
-                           { 9, { { 0, 35.5 }, { 3, 36.0 } } },
-                           { 10, { { 0, 35.3 }, { 3, 35.9 } } } } },
+                         { { 5, { { 0, 35.0 }, { 3, 35.0 } } },
+                           { 6, { { 0, 35.0 }, { 3, 35.0 } } },
+                           { 7, { { 0, 34.0 }, { 3, 34.0 } } },
+                           { 8, { { 0, 34.0 }, { 3, 35.0 } } },
+                           { 9, { { 0, 34.0 }, { 3, 34.0 } } },
+                           { 10, { { 0, 34.0 }, { 3, 34.0 } } } } },
                        { "niklas_1280_720_30.y4m",
-                         { { 5, { { 0, 34.4 }, { 3, 34.2 } } },
-                           { 6, { { 0, 34.1 }, { 3, 34.0 } } },
-                           { 7, { { 0, 33.5 }, { 3, 33.1 } } },
-                           { 8, { { 0, 33.3 }, { 3, 33.3 } } },
-                           { 9, { { 0, 33.3 }, { 3, 33.3 } } },
-                           { 10, { { 0, 33.1 }, { 3, 33.1 } } } } },
+                         { { 5, { { 0, 32.0 }, { 3, 32.0 } } },
+                           { 6, { { 0, 32.0 }, { 3, 32.0 } } },
+                           { 7, { { 0, 31.0 }, { 3, 31.0 } } },
+                           { 8, { { 0, 31.0 }, { 3, 31.0 } } },
+                           { 9, { { 0, 31.0 }, { 3, 31.0 } } },
+                           { 10, { { 0, 31.0 }, { 3, 31.0 } } } } },
                        { "hantro_collage_w352h288_nv12.yuv",
-                         { { 5, { { 0, 34.4 }, { 3, 34.2 } } },
-                           { 6, { { 0, 34.1 }, { 3, 34.1 } } },
-                           { 7, { { 0, 33.6 }, { 3, 33.6 } } },
-                           { 8, { { 0, 33.3 }, { 3, 33.3 } } },
-                           { 9, { { 0, 33.3 }, { 3, 33.3 } } },
-                           { 10, { { 0, 33.1 }, { 3, 33.1 } } } } } };
+                         { { 5, { { 0, 32.0 }, { 3, 32.0 } } },
+                           { 6, { { 0, 32.0 }, { 3, 32.0 } } },
+                           { 7, { { 0, 32.0 }, { 3, 32.0 } } },
+                           { 8, { { 0, 32.0 }, { 3, 32.0 } } },
+                           { 9, { { 0, 31.0 }, { 3, 31.0 } } },
+                           { 10, { { 0, 31.0 }, { 3, 31.0 } } } } } };
 
 typedef struct {
   const char *filename;
