@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2016, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -14,7 +14,7 @@
 #include <string>
 #include <tuple>
 
-#include "third_party/googletest/src/googletest/include/gtest/gtest.h"
+#include "gtest/gtest.h"
 
 #include "config/aom_config.h"
 #include "config/aom_dsp_rtcd.h"
@@ -780,6 +780,7 @@ INSTANTIATE_TEST_SUITE_P(NEON_DOTPROD, Lowbd2dVarTest,
 
 #endif  // HAVE_NEON_DOTPROD
 
+#if CONFIG_AV1_HIGHBITDEPTH
 class Highbd2dVarTest : public ::testing::TestWithParam<TestFuncVar2D> {
  public:
   ~Highbd2dVarTest() override = default;
@@ -925,4 +926,5 @@ INSTANTIATE_TEST_SUITE_P(SVE, Highbd2dVarTest,
                                                          &aom_var_2d_u16_sve)));
 
 #endif  // HAVE_SVE
+#endif  // CONFIG_AV1_HIGHBITDEPTH
 }  // namespace
