@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020, Alliance for Open Media. All rights reserved
+ * Copyright (c) 2020, Alliance for Open Media. All rights reserved.
  *
  * This source code is subject to the terms of the BSD 2 Clause License and
  * the Alliance for Open Media Patent License 1.0. If the BSD 2 Clause License
@@ -11,7 +11,7 @@
 
 #include "aom/aom_codec.h"
 #include "aom_dsp/aom_dsp_common.h"
-#include "third_party/googletest/src/googletest/include/gtest/gtest.h"
+#include "gtest/gtest.h"
 #include "test/codec_factory.h"
 #include "test/encode_test_driver.h"
 #include "test/y4m_video_source.h"
@@ -62,7 +62,7 @@ const nonUniformTileConfigParam nonUniformTileConfigParams[] = {
 };
 
 // Find smallest k>=0 such that (blk_size << k) >= target
-static INLINE int tile_log2(int blk_size, int target) {
+static inline int tile_log2(int blk_size, int target) {
   int k;
   for (k = 0; (blk_size << k) < target; k++) {
   }
